@@ -1,10 +1,10 @@
-/* $Header: /fridge/cvs/xscorch/libj/jstr/str_comp.c,v 1.14 2004/02/26 05:56:53 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/libj/jstr/str_comp.c,v 1.16 2011-08-01 00:01:39 jacob Exp $ */
 /*
 
    libj - str_comp.c             Copyright (C) 1998-2003 Justin David Smith
                                  Copyright (C) 2003 Jacob Luna Lundberg
    justins (a) chaos2.org        http://chaos2.org/
-   jacob (a) chaos2.org          http://chaos2.org/~jacob
+   jacob (a) chaos2.org          http://www.gnifty.net/
 
    String Comparison functions
 
