@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/libj/jstr/str_creat.c,v 1.7 2004/02/26 05:56:53 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/libj/jstr/str_creat.c,v 1.8 2009-04-26 17:39:30 jacob Exp $ */
 /*
 
    libj - str_creat.c            Copyright (C) 1998-2003 Justin David Smith
@@ -18,7 +18,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this library; if not, write to the Free Software Foundation, Inc.,
-   59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
    This file is part of LIBJ.
 
