@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sai/sai.c,v 1.10 2004/02/26 06:34:54 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sai/sai.c,v 1.12 2009-04-26 17:39:34 jacob Exp $ */
 /*
    
    xscorch - sai.c            Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <saiint.h>              /* Main AI internal header */
@@ -31,7 +31,7 @@
 
 
 
-void sc_ai_init_game(unused const struct _sc_config *c, sc_player *p) {
+void sc_ai_init_game(__libj_unused const struct _sc_config *c, sc_player *p) {
 /* sc_ai_init_game */
 
    if(p->aitype == SC_AI_RANDOM) {
@@ -46,7 +46,7 @@ void sc_ai_init_game(unused const struct _sc_config *c, sc_player *p) {
 
 
 
-void sc_ai_init_round(unused const struct _sc_config *c, sc_player *p) {
+void sc_ai_init_round(__libj_unused const struct _sc_config *c, sc_player *p) {
 /* sc_ai_init_round */
 
    p->ai->victim = NULL;
