@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sconsole/swindow-console.h,v 1.3 2004/02/26 06:34:54 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sconsole/swindow-console.h,v 1.4 2009-04-26 17:39:36 jacob Exp $ */
 /*
    
    xscorch - swindow-console.h   Copyright(c) 2001 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __swindow_console_h_included
