@@ -1,9 +1,9 @@
-/* $Header: /fridge/cvs/xscorch/sgame/saccessory.c,v 1.30 2004/03/25 04:55:06 jacob Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/saccessory.c,v 1.34 2011-08-01 00:01:40 jacob Exp $ */
 /*
 
-   xscorch - saccessory.c     Copyright(c) 2000-2003 Jacob Luna Lundberg
+   xscorch - saccessory.c     Copyright(c) 2000-2004 Jacob Luna Lundberg
                               Copyright(c) 2000-2003 Justin David Smith
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
    justins(at)chaos2.org      http://chaos2.org/
 
    Scorched tank accessories
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <assert.h>
@@ -64,7 +64,7 @@ static inline bool _sc_accessory_viewable(const sc_accessory_config *ac, const s
 
 
 
-static bool _sc_accessory_test_count(void *data, int arg) {
+static bool _sc_accessory_test_count(void *data, long arg) {
 /* _sc_accessory_test_count
    This is an sc_registry_test function.
    We will iterate, incrementing a counter, but always returning false. */
@@ -99,7 +99,7 @@ int sc_accessory_count(const sc_accessory_config *ac, int flags) {
    ata.flags   = flags;
    ata.ac      = ac;
    iter = sc_registry_iter_new(ac->registry, ac->registryclass, SC_REGISTRY_FORWARD,
-                               _sc_accessory_test_count, (int)(&ata));
+                               _sc_accessory_test_count, (long)(&ata));
    if(iter == NULL) return(0);
 
    /* Iterate using the fast registry iterators. */
@@ -135,7 +135,7 @@ sc_accessory_info *sc_accessory_lookup(const sc_accessory_config *ac, int id, in
 
 
 
-static bool _sc_accessory_test_lookup_name(void *data, int arg) {
+static bool _sc_accessory_test_lookup_name(void *data, long arg) {
 /* _sc_accessory_test_lookup_name
    This is an sc_registry_test function.
    We will seek, search, discover the accessory by name. */
@@ -166,13 +166,9 @@ sc_accessory_info *sc_accessory_lookup_by_name(const sc_accessory_config *ac, co
 
    /* Set up for iteration. */
    ata.name = name;
-   if(flags & SC_ACCESSORY_SCAN_REVERSE) {
-      iter = sc_registry_iter_new(ac->registry, ac->registryclass, SC_REGISTRY_REVERSE,
-                                  _sc_accessory_test_lookup_name, (int)(&ata));
-   } else {
-      iter = sc_registry_iter_new(ac->registry, ac->registryclass, SC_REGISTRY_FORWARD,
-                                  _sc_accessory_test_lookup_name, (int)(&ata));
-   }
+   iter = sc_registry_iter_new(ac->registry, ac->registryclass,
+                               (flags & SC_ACCESSORY_SCAN_REVERSE) ? SC_REGISTRY_REVERSE : SC_REGISTRY_FORWARD,
+                               _sc_accessory_test_lookup_name, (long)(&ata));
    if(iter == NULL) return(NULL);
 
    /* Iterate using the fast registry iterators. */
@@ -191,7 +187,7 @@ sc_accessory_info *sc_accessory_lookup_by_name(const sc_accessory_config *ac, co
 
 
 
-static bool _sc_accessory_test_viewable(void *data, int arg) {
+static bool _sc_accessory_test_viewable(void *data, long arg) {
 /* _sc_accessory_test_viewable
    This is an sc_registry_test function.
    We will return true for the first viewable accessory. */
@@ -222,13 +218,9 @@ sc_accessory_info *sc_accessory_first(const sc_accessory_config *ac, int flags)
    ata.flags = flags;
 
    /* Try and find the first/last accessory that meets our criteria. */
-   if(flags & SC_ACCESSORY_SCAN_REVERSE) {
-      info = sc_registry_find_first(ac->registry, ac->registryclass, SC_REGISTRY_REVERSE,
-                                    _sc_accessory_test_viewable, (int)(&ata));
-   } else {
-      info = sc_registry_find_first(ac->registry, ac->registryclass, SC_REGISTRY_FORWARD,
-                                    _sc_accessory_test_viewable, (int)(&ata));
-   }
+   info = sc_registry_find_first(ac->registry, ac->registryclass,
+                                 (flags & SC_ACCESSORY_SCAN_REVERSE) ? SC_REGISTRY_REVERSE : SC_REGISTRY_FORWARD,
+                                 _sc_accessory_test_viewable, (long)(&ata));
 
    return(info);
 
@@ -239,7 +231,6 @@ sc_accessory_info *sc_accessory_next(const sc_accessory_config *ac, const sc_acc
 /* sc_accessory_next
    Advance to the next/prev accessory in the list (with wrapping).  */
 
-   int regflag;
    sc_accessory_test_arg ata;
    sc_accessory_info *nxtnfo;
 
@@ -248,14 +239,11 @@ sc_accessory_info *sc_accessory_next(const sc_accessory_config *ac, const sc_acc
    /* Set up the flags and args for the mission. */
    ata.ac    = ac;
    ata.flags = flags;
-   if(flags & SC_ACCESSORY_SCAN_REVERSE)
-      regflag = SC_REGISTRY_REVERSE;
-   else
-      regflag = SC_REGISTRY_FORWARD;
 
    /* Try and find the first/last accessory that meets our criteria. */
-   nxtnfo = sc_registry_find_next(ac->registry, ac->registryclass, info->ident, regflag,
-                                  _sc_accessory_test_viewable, (int)(&ata));
+   nxtnfo = sc_registry_find_next(ac->registry, ac->registryclass, info->ident,
+                                  (flags & SC_ACCESSORY_SCAN_REVERSE) ? SC_REGISTRY_REVERSE : SC_REGISTRY_FORWARD,
+                                  _sc_accessory_test_viewable, (long)(&ata));
 
    /* In case we iterated off the end of the list, wrap to the beginning. */
    if(nxtnfo == NULL)
@@ -431,7 +419,7 @@ void sc_accessory_info_free(sc_accessory_info **ai) {
 
 
 
-static bool _sc_accessory_inventory_clear_func(void *data, unused int arg) {
+static bool _sc_accessory_inventory_clear_func(void *data, __libj_unused long arg) {
 /* _sc_accessory_inventory_clear_func
    Clear accessory inventory data, in registry fast iterators. */
 
