@@ -1,8 +1,8 @@
-/* $Header: /fridge/cvs/xscorch/sgame/saddconf.c,v 1.46 2004/02/26 06:34:54 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/saddconf.c,v 1.49 2011-08-01 00:01:40 jacob Exp $ */
 /*
 
    xscorch - saddconf.c       Copyright(c) 2001-2003 Jacob Luna Lundberg
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Scorched read/append config files
 
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <assert.h>
@@ -178,8 +178,8 @@ bool _sc_scoring_read_item(sc_economy_config *ec, reg *reader, reg_var *item) {
    Read an economy scoring info and insert it into the registry. */
 
    sc_scoring_info *info;
-   char desc[SC_INVENTORY_MAX_DESC_LEN];
-   char name[SC_INVENTORY_MAX_NAME_LEN];
+   char desc[SC_ECONOMY_MAX_DESC_LEN];
+   char name[SC_ECONOMY_MAX_NAME_LEN];
 
    assert(ec != NULL);
    assert(reader != NULL);
@@ -224,7 +224,7 @@ bool _sc_scoring_read_item(sc_economy_config *ec, reg *reader, reg_var *item) {
    reg_get_boolean(reader, item, "fixed",         &info->fixed);
 
    /* Read in the scoring description if there is one. */
-   if(!reg_get_string(reader, item, "description", desc, SC_INVENTORY_MAX_DESC_LEN) || desc[0] == '\0') {
+   if(!reg_get_string(reader, item, "description", desc, SC_ECONOMY_MAX_DESC_LEN) || desc[0] == '\0') {
       info->description = NULL;
    } else {
       info->description = (char *)malloc(strlenn(desc) + 1);
