@@ -1,10 +1,10 @@
-/* $Header: /fridge/cvs/xscorch/sgame/seconomy.c,v 1.14 2004/02/26 06:34:54 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/seconomy.c,v 1.17 2011-08-01 00:01:41 jacob Exp $ */
 /*
    
    xscorch - seconomy.c       Copyright(c) 2000      Justin David Smith
                               Copyright(c) 2003-2004 Jacob Luna Lundberg
    justins(at)chaos2.org      http://chaos2.org/
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Scorched economy
     
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <assert.h>
@@ -204,7 +204,7 @@ sc_scoring_info *sc_scoring_lookup(const sc_economy_config *ec, int id) {
 
 
 
-bool _sc_scoring_test_lookup_name(void *data, int arg) {
+bool _sc_scoring_test_lookup_name(void *data, long arg) {
 /* _sc_scoring_test_lookup_name
    This is an sc_registry_test function.
    We will select from the registry by name. */
@@ -234,7 +234,7 @@ sc_scoring_info *sc_scoring_lookup_by_name(const sc_economy_config *ec, const ch
 
    /* Set up for iteration. */
    iter = sc_registry_iter_new(ec->registry, ec->registryclass, SC_REGISTRY_FORWARD,
-                               _sc_scoring_test_lookup_name, (int)(name));
+                               _sc_scoring_test_lookup_name, (long)(name));
    if(iter == NULL) return(NULL);
 
    /* Iterate using the fast registry iterators. */
