@@ -1,11 +1,11 @@
-/* $Header: /fridge/cvs/xscorch/sgame/sexplosion.c,v 1.16 2004/02/26 06:34:54 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/sexplosion.c,v 1.18 2011-08-01 00:01:41 jacob Exp $ */
 /*
 
    xscorch - sexplosion.c     Copyright(c) 2000-2003 Justin David Smith
                               Copyright(c) 2000-2003 Jacob Luna Lundberg
                               Copyright(c) 2003 Jason House (wedge code)
    justins(at)chaos2.org      http://chaos2.org/
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Scorched zone explosions
 
@@ -19,9 +19,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <assert.h>
