@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgame/sland.c,v 1.14 2004/02/26 06:34:54 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/sland.c,v 1.16 2011-07-31 18:29:19 jacob Exp $ */
 /*
 
    xscorch - sland.c          Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sland.h>
@@ -828,6 +828,7 @@ void sc_land_level_around(const sc_config *c, sc_land *l, int x, int w, int ht)
    x2 = x + w;
 
    /* Level the columns in the interval. */
+   cx = 0;
    for(x = x1; cx <= x2; ++x) {
       cx = x;
       if(_sc_land_translate_x(l, &cx)) {
@@ -1157,7 +1158,6 @@ bool sc_land_line_of_sight(const sc_config *c, const sc_land *l, int x1, int y1,
    wrapping boundaries and solid walls into account, if they are available.
    x1, y1, x2, y2 are all virtual coordinates.  */
 
-   sc_physics_walls walls; /* Current wall type */
    double x;               /* Current X coordinate */
    double y;               /* Current Y coordinate */
    double stepx;           /* Step X, per iteration */
@@ -1171,9 +1171,6 @@ bool sc_land_line_of_sight(const sc_config *c, const sc_land *l, int x1, int y1,
    /* Sanity checks */
    if(c == NULL || l == NULL) return(false);
 
-   /* Setup basic variables.. */
-   walls = c->physics->walls;
-
    /* Determine the distance between points */
    deltax = x2 - x1;
    deltay = y2 - y1;
