@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgame/slscape.c,v 1.4 2003/02/25 02:49:26 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/slscape.c,v 1.6 2009-04-26 17:39:41 jacob Exp $ */
 /*
 
   slscape.c
@@ -16,11 +16,11 @@
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
  
-  You should have received a copy of the GNU General Public License
+   You should have received a copy of the GNU General Public License along
   along with this program; if not, write to 
  
      The Free Software Foundation, Inc.
-     59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  
 */
 #include <math.h>
@@ -58,7 +58,7 @@ static double _sc_lscape_eval_valley(double x);
 
 
 
-static double _sc_lscape_eval_none(unused double x) {
+static double _sc_lscape_eval_none(__libj_unused double x) {
 /* _sc_lscape_eval_none
    Evaluates a null profile. */
    
