@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgame/slscapetools.h,v 1.3 2003/02/20 11:28:59 jacob Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/slscapetools.h,v 1.4 2009-04-26 17:39:41 jacob Exp $ */
 /*--------------------------------------------------------------------
  *
  *  slscapetools.h
@@ -19,7 +19,7 @@
  *  along with this program; if not, write to 
  *
  *    The Free Software Foundation, Inc.
- *    59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  * 
  */
 
