@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgame/soptions.c,v 1.20 2004/03/11 06:22:01 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/soptions.c,v 1.21 2009-04-26 17:39:41 jacob Exp $ */
 /*
 
    xscorch - soptions.c       Copyright(c) 2000-2004 Justin David Smith
@@ -17,9 +17,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <getopt.h>
