@@ -1,8 +1,8 @@
-/* $Header: /fridge/cvs/xscorch/sgame/sphoenix.c,v 1.27 2004/02/26 06:34:54 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/sphoenix.c,v 1.31 2011-08-01 00:01:41 jacob Exp $ */
 /*
 
    xscorch - sphoenix.c       Copyright(c) 2000-2003 Jacob Luna Lundberg
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Scorched phoenix type weapons calls
 
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <math.h>
@@ -41,7 +41,7 @@
 
 
 
-static sc_phoenix_result _sc_phoenix_chain(unused int locate, const sc_config *c, sc_weapon **wp, sc_explosion **e) {
+static sc_phoenix_result _sc_phoenix_chain(__libj_unused int locate, const sc_config *c, sc_weapon **wp, sc_explosion **e) {
 /* _sc_phoenix_chain
    Split a missile with detonation on land and bounce a child if it has any */
 
@@ -108,7 +108,7 @@ static sc_phoenix_result _sc_phoenix_chain(unused int locate, const sc_config *c
 
 
 
-static sc_phoenix_result _sc_phoenix_spider(unused int locate, const sc_config *c, sc_weapon **wp, sc_explosion **e) {
+static sc_phoenix_result _sc_phoenix_spider(__libj_unused int locate, const sc_config *c, sc_weapon **wp, sc_explosion **e) {
 /* _sc_phoenix_spider
    Split a missile with detonation on land and give random destinations */
 
@@ -183,7 +183,7 @@ static sc_phoenix_result _sc_phoenix_spider(unused int locate, const sc_config *
 
 
 
-static sc_phoenix_result _sc_phoenix_scatter(unused int locate, const sc_config *c, sc_weapon **wp, unused sc_explosion **e) {
+static sc_phoenix_result _sc_phoenix_scatter(__libj_unused int locate, const sc_config *c, sc_weapon **wp, __libj_unused sc_explosion **e) {
 /* _sc_phoenix_scatter
    Scatter a missile without detonation */
 
@@ -250,7 +250,7 @@ static sc_phoenix_result _sc_phoenix_scatter(unused int locate, const sc_config
 
 
 
-static sc_phoenix_result _sc_phoenix_convert(unused int locate, const sc_config *c, sc_weapon **wp, sc_explosion **e) {
+static sc_phoenix_result _sc_phoenix_convert(__libj_unused int locate, const sc_config *c, sc_weapon **wp, sc_explosion **e) {
 /* sc_phoenix_convert
  * Convert a weapon to a new trajectory handler */
 
@@ -259,10 +259,6 @@ static sc_phoenix_result _sc_phoenix_convert(unused int locate, const sc_config
    int ph_count;
    int flags;
 
-   /* What shall we reincarnate as? */
-   ph_type = SC_PHOENIX_CHILD_TYPE((*wp)->weaponinfo);
-   ph_count = SC_PHOENIX_CHILD_COUNT((*wp)->weaponinfo);
-
    /* We'll need the weapon flags. */
    flags = SC_WEAPON_TRAJ_FLAGS(c, *wp);
 
