@@ -1,8 +1,8 @@
-/* $Header: /fridge/cvs/xscorch/sgame/sregistry.c,v 1.5 2004/02/26 06:34:54 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/sregistry.c,v 1.8 2011-08-01 00:01:41 jacob Exp $ */
 /*
 
-   xscorch - sregistry.c      Copyright(c) 2003 Jacob Luna Lundberg
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   xscorch - sregistry.c      Copyright(c) 2003-2004 Jacob Luna Lundberg
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Scorched runtime fast data registry
 
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sregistry.h>
@@ -27,10 +27,6 @@
 
 
 
-bool (*test)(void *, int);
-
-
-
 sc_registry *sc_registry_new(void) {
 /* sc_registry_new
    Allocate and initialize a new registry. */
@@ -190,7 +186,7 @@ void *sc_registry_find_by_string(const sc_registry *registry, const char *key) {
 
 
 
-inline shashlist_item *_sc_registry_internal_iter(shashlist *list, shashlist_item *item, int class, sc_registry_direction direction, sc_registry_test_func function, int arg) {
+inline shashlist_item *_sc_registry_internal_iter(shashlist *list, shashlist_item *item, int class, sc_registry_direction direction, sc_registry_test_func function, long arg) {
 /* _sc_registry_internal_iter
    Local function to find the next or prev entry in a set. */
 
@@ -213,7 +209,7 @@ inline shashlist_item *_sc_registry_internal_iter(shashlist *list, shashlist_ite
 
 
 
-void *sc_registry_find_first(const sc_registry *registry, int class, sc_registry_direction direction, sc_registry_test_func function, int arg) {
+void *sc_registry_find_first(const sc_registry *registry, int class, sc_registry_direction direction, sc_registry_test_func function, long arg) {
 /* sc_registry_find_first
    Find the first item of a given class. */
 
@@ -233,7 +229,7 @@ void *sc_registry_find_first(const sc_registry *registry, int class, sc_registry
 }
 
 
-void *sc_registry_find_next(const sc_registry *registry, int class, int key, sc_registry_direction direction, sc_registry_test_func function, int arg) {
+void *sc_registry_find_next(const sc_registry *registry, int class, int key, sc_registry_direction direction, sc_registry_test_func function, long arg) {
 /* sc_registry_find_next
    Find the next item of a given class, given an item. */
 
@@ -255,7 +251,7 @@ void *sc_registry_find_next(const sc_registry *registry, int class, int key, sc_
 
 
 
-sc_registry_iter *sc_registry_iter_new(const sc_registry *registry, int class, sc_registry_direction direction, sc_registry_test_func function, int arg) {
+sc_registry_iter *sc_registry_iter_new(const sc_registry *registry, int class, sc_registry_direction direction, sc_registry_test_func function, long arg) {
 /* sc_registry_iter_new
    Allocate an sc_registry_iter struct for fast registry set iteration. */
 
