@@ -1,11 +1,11 @@
-/* $Header: /fridge/cvs/xscorch/sgame/sshield.c,v 1.39 2003/02/27 05:46:52 jacob Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/sshield.c,v 1.41 2011-08-01 00:01:41 jacob Exp $ */
 /*
 
    xscorch - sshield.c        Copyright(c) 2000-2003 Justin David Smith
                               Copyright(c) 2000-2003 Jacob Luna Lundberg
                               Copyright(c) 2003           Jason House
    justins(at)chaos2.org      http://chaos2.org/
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Scorched shields
 
@@ -20,9 +20,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <math.h>
