@@ -1,10 +1,10 @@
-/* $Header: /fridge/cvs/xscorch/sgame/strack.c,v 1.25 2004/02/26 06:34:54 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/strack.c,v 1.28 2011-08-01 00:01:41 jacob Exp $ */
 /*
 
    xscorch - strack.c         Copyright(c) 2000-2003 Justin David Smith
                               Copyright(c) 2003      Jacob Luna Lundberg
    justins(at)chaos2.org      http://chaos2.org/
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Scorched basic weapon tracking
 
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <assert.h>
@@ -181,7 +181,7 @@ static sc_weapon_track_result _sc_weapon_track(sc_config *c, sc_weapon **wp, sc_
 
    /* Deal damage to shields if appropriate */
    if(stepres == SC_TRAJ_IMPACT_SHIELD && !SC_WEAPON_IS_LIQUID(*wp)) {
-      sc_shield_absorb_hit(c->players[traj->victim], SC_WEAPON_IS_SAPPER(*wp));
+      sc_shield_absorb_hit(c->players[traj->victim], SC_WEAPON_IS_SAPPER(*wp) ? 1 : 0);
       stepres = SC_TRAJ_SIZZLE;
    }
 
