@@ -1,9 +1,9 @@
-/* $Header: /fridge/cvs/xscorch/sgame/sweapon.c,v 1.71 2004/03/25 04:55:06 jacob Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/sweapon.c,v 1.75 2011-08-01 00:01:42 jacob Exp $ */
 /*
 
-   xscorch - sweapon.c        Copyright(c) 2000-2003 Jacob Luna Lundberg
+   xscorch - sweapon.c        Copyright(c) 2000-2004 Jacob Luna Lundberg
                               Copyright(c) 2000-2003 Justin David Smith
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
    justins(at)chaos2.org      http://chaos2.org/
 
    Scorched basic weapon system
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <assert.h>
@@ -76,7 +76,7 @@ static inline bool _sc_weapon_viewable(const sc_weapon_config *wc, const sc_weap
 
 
 
-static bool _sc_weapon_test_count(void *data, int arg) {
+static bool _sc_weapon_test_count(void *data, long arg) {
 /* _sc_weapon_test_count
    This is an sc_registry_test function.
    We will iterate, incrementing a counter, but always returning false. */
@@ -111,7 +111,7 @@ int sc_weapon_count(const sc_weapon_config *wc, int flags) {
    wta.flags   = flags;
    wta.wc      = wc;
    iter = sc_registry_iter_new(wc->registry, wc->registryclass, SC_REGISTRY_FORWARD,
-                               _sc_weapon_test_count, (int)(&wta));
+                               _sc_weapon_test_count, (long)(&wta));
    if(iter == NULL) return(0);
 
    /* Iterate using the fast registry iterators. */
@@ -147,7 +147,7 @@ sc_weapon_info *sc_weapon_lookup(const sc_weapon_config *wc, int id, int flags)
 
 
 
-static bool _sc_weapon_test_lookup_name(void *data, int arg) {
+static bool _sc_weapon_test_lookup_name(void *data, long arg) {
 /* _sc_weapon_test_lookup_name
    This is an sc_registry_test function.
    We will seek, search, discover the weapon by name. */
@@ -178,13 +178,9 @@ sc_weapon_info *sc_weapon_lookup_by_name(const sc_weapon_config *wc, const char
 
    /* Set up for iteration. */
    wta.name = name;
-   if(flags & SC_WEAPON_SCAN_REVERSE) {
-      iter = sc_registry_iter_new(wc->registry, wc->registryclass, SC_REGISTRY_REVERSE,
-                                  _sc_weapon_test_lookup_name, (int)(&wta));
-   } else {
-      iter = sc_registry_iter_new(wc->registry, wc->registryclass, SC_REGISTRY_FORWARD,
-                                  _sc_weapon_test_lookup_name, (int)(&wta));
-   }
+   iter = sc_registry_iter_new(wc->registry, wc->registryclass,
+                               (flags & SC_WEAPON_SCAN_REVERSE) ? SC_REGISTRY_REVERSE : SC_REGISTRY_FORWARD,
+                               _sc_weapon_test_lookup_name, (long)(&wta));
    if(iter == NULL) return(NULL);
 
    /* Iterate using the fast registry iterators. */
@@ -203,7 +199,7 @@ sc_weapon_info *sc_weapon_lookup_by_name(const sc_weapon_config *wc, const char
 
 
 
-static bool _sc_weapon_test_viewable(void *data, int arg) {
+static bool _sc_weapon_test_viewable(void *data, long arg) {
 /* _sc_weapon_test_viewable
    This is an sc_registry_test function.
    We will return true for the first viewable weapon. */
@@ -234,13 +230,9 @@ sc_weapon_info *sc_weapon_first(const sc_weapon_config *wc, int flags) {
    wta.flags = flags;
 
    /* Try and find the first/last weapon that meets our criteria. */
-   if(flags & SC_WEAPON_SCAN_REVERSE) {
-      info = sc_registry_find_first(wc->registry, wc->registryclass, SC_REGISTRY_REVERSE,
-                                    _sc_weapon_test_viewable, (int)(&wta));
-   } else {
-      info = sc_registry_find_first(wc->registry, wc->registryclass, SC_REGISTRY_FORWARD,
-                                    _sc_weapon_test_viewable, (int)(&wta));
-   }
+   info = sc_registry_find_first(wc->registry, wc->registryclass,
+                                 (flags & SC_WEAPON_SCAN_REVERSE) ? SC_REGISTRY_REVERSE : SC_REGISTRY_FORWARD,
+                                 _sc_weapon_test_viewable, (long)(&wta));
 
    return(info);
 
@@ -251,7 +243,6 @@ sc_weapon_info *sc_weapon_next(const sc_weapon_config *wc, const sc_weapon_info
 /* sc_weapon_next
    Advance to the next/prev weapon in the list (with wrapping).  */
 
-   int regflag;
    sc_weapon_test_arg wta;
    sc_weapon_info *nxtnfo;
 
@@ -260,14 +251,11 @@ sc_weapon_info *sc_weapon_next(const sc_weapon_config *wc, const sc_weapon_info
    /* Set up the flags and args for the mission. */
    wta.wc    = wc;
    wta.flags = flags;
-   if(flags & SC_WEAPON_SCAN_REVERSE)
-      regflag = SC_REGISTRY_REVERSE;
-   else
-      regflag = SC_REGISTRY_FORWARD;
 
    /* Try and find the first/last weapon that meets our criteria. */
-   nxtnfo = sc_registry_find_next(wc->registry, wc->registryclass, info->ident, regflag,
-                                  _sc_weapon_test_viewable, (int)(&wta));
+   nxtnfo = sc_registry_find_next(wc->registry, wc->registryclass, info->ident,
+                                  (flags & SC_WEAPON_SCAN_REVERSE) ? SC_REGISTRY_REVERSE : SC_REGISTRY_FORWARD,
+                                  _sc_weapon_test_viewable, (long)(&wta));
 
    /* In case we iterated off the end of the list, wrap to the beginning. */
    if(nxtnfo == NULL)
@@ -891,7 +879,7 @@ void sc_weapon_info_free(sc_weapon_info **wi) {
 
 
 
-bool _sc_weapon_inventory_clear_func(void *data, unused int arg) {
+bool _sc_weapon_inventory_clear_func(void *data, __libj_unused long arg) {
 /* _sc_weapon_inventory_clear_func
    Clear weapon inventory data, in registry fast iterators. */
 
