@@ -1,9 +1,9 @@
-/* $Header: /fridge/cvs/xscorch/sgame/sweapon.h,v 1.57 2004/03/25 04:55:06 jacob Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgame/sweapon.h,v 1.59 2011-08-01 00:01:42 jacob Exp $ */
 /*
 
    xscorch - sweapon.h        Copyright(c) 2000-2003 Jacob Luna Lundberg
                               Copyright(c) 2000-2003 Justin David Smith
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
    justins(at)chaos2.org      http://chaos2.org/
 
    Scorched basic weapon configuration
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __sweapon_h_included
