@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/sai-gtk.c,v 1.12 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/sai-gtk.c,v 1.14 2009-04-26 17:39:47 jacob Exp $ */
 /*
    
    xscorch - sai-gtk.c        Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sgtk.h>
@@ -47,7 +47,7 @@ typedef struct _sc_ai_controller_setup_data_gtk {
 
 
 
-static void _sc_ai_controller_setup_apply_gtk(unused ScDialog *dlg, sc_ai_controller_setup_data_gtk *setup) {
+static void _sc_ai_controller_setup_apply_gtk(__libj_unused ScDialog *dlg, sc_ai_controller_setup_data_gtk *setup) {
 
    sc_ai_controller *aic = setup->aic;
    
@@ -82,13 +82,8 @@ void sc_ai_controller_setup_gtk(sc_window_gtk *w) {
    setup.nobudget = aic->nobudget;
 
    dialog = SC_DIALOG(sc_dialog_new("AI Controller Setup", NULL, confirm | SC_DIALOG_CANCEL));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(dialog), "apply",
-                         GTK_SIGNAL_FUNC(_sc_ai_controller_setup_apply_gtk), &setup);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(dialog), "apply",
-                       (GCallback)_sc_ai_controller_setup_apply_gtk, &setup);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(dialog), "apply",
+                    (GCallback)_sc_ai_controller_setup_apply_gtk, &setup);
 
    attach_option(dialog, w, "Human Target Practice",  sc_link_check_new(&setup.humantargets), &row);
    attach_option(dialog, w, "Allow Offset Targetting",sc_link_check_new(&setup.allowoffsets), &row);
@@ -99,6 +94,3 @@ void sc_ai_controller_setup_gtk(sc_window_gtk *w) {
    sc_dialog_run(dialog);
 
 }
-
-
-
