@@ -1,9 +1,9 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/sautodef-gtk.c,v 1.33 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/sautodef-gtk.c,v 1.36 2011-08-01 00:01:42 jacob Exp $ */
 /*
 
    xscorch - sautodef-gtk.c   Copyright(c) 2001-2003 Jacob Luna Lundberg
                               Copyright(c) 2003 Justin David Smith
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
    justins(at)chaos2.org      http://chaos2.org/
 
    Auto Defense settings screen
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <math.h>
@@ -156,8 +156,8 @@ inline void _sc_window_auto_def_engage(sc_auto_def_gtk *adg) {
 
 
 
-static gboolean _sc_window_auto_def_close_gtk(unused GtkWidget *widget,
-                                              unused ScActiveConsoleSpot *spot,
+static gboolean _sc_window_auto_def_close_gtk(__libj_unused GtkWidget *widget,
+                                              __libj_unused ScActiveConsoleSpot *spot,
                                               sc_auto_def_gtk *adg) {
 /* _sc_window_auto_def_close_gtk
    Enact the auto defense settings and restart the auto defense loop. */
@@ -184,8 +184,8 @@ static gboolean _sc_window_auto_def_close_gtk(unused GtkWidget *widget,
 
 
 
-static gboolean _sc_window_auto_def_key_gtk(unused GtkWidget *widget,
-                                            unused ScActiveConsoleSpot *spot,
+static gboolean _sc_window_auto_def_key_gtk(__libj_unused GtkWidget *widget,
+                                            __libj_unused ScActiveConsoleSpot *spot,
                                             GdkEventKey *key, sc_auto_def_gtk *adg) {
 /* _sc_window_auto_def_key_gtk
    Enact the auto defense settings and restart the auto defense loop. */
@@ -216,7 +216,7 @@ static gboolean _sc_window_auto_def_key_gtk(unused GtkWidget *widget,
 
 
 
-static gboolean _sc_autodef_guidance_enter_gtk(unused ScActiveConsole *cons,
+static gboolean _sc_autodef_guidance_enter_gtk(__libj_unused ScActiveConsole *cons,
                                                ScActiveConsoleSpot *spot,
                                                sc_auto_def_gtk *adg) {
 /* _sc_autodef_guidance_enter_gtk
@@ -246,7 +246,7 @@ static gboolean _sc_autodef_guidance_enter_gtk(unused ScActiveConsole *cons,
 
 
 
-static gboolean _sc_autodef_shield_enter_gtk(unused ScActiveConsole *cons,
+static gboolean _sc_autodef_shield_enter_gtk(__libj_unused ScActiveConsole *cons,
                                              ScActiveConsoleSpot *spot,
                                              sc_auto_def_gtk *adg) {
 /* _sc_autodef_shield_enter_gtk
@@ -333,17 +333,10 @@ void _sc_window_auto_defense_guidance_init(sc_auto_def_gtk *adg) {
     * just enter_spot.  Can you think of others that would be useful?
     * I can't.  :)
     */
-   #if GTK12_ENABLED
-      gtk_signal_connect_after(GTK_OBJECT(adg->console_guidance), "enter-spot",
-                               GTK_SIGNAL_FUNC(_sc_autodef_guidance_enter_gtk), adg);
-      gtk_signal_connect_after(GTK_OBJECT(adg->console_guidance), "key_press_spot",
-                               GTK_SIGNAL_FUNC(_sc_window_auto_def_key_gtk), adg);
-   #else /* GTK 2.0 */
-      g_signal_connect_after(G_OBJECT(adg->console_guidance), "enter-spot",
-                             (GCallback)_sc_autodef_guidance_enter_gtk, adg);
-      g_signal_connect_after(G_OBJECT(adg->console_guidance), "key_press_spot",
-                             (GCallback)_sc_window_auto_def_key_gtk, adg);
-   #endif /* GTK version? */
+   g_signal_connect_after(G_OBJECT(adg->console_guidance), "enter-spot",
+                          (GCallback)_sc_autodef_guidance_enter_gtk, adg);
+   g_signal_connect_after(G_OBJECT(adg->console_guidance), "key_press_spot",
+                          (GCallback)_sc_window_auto_def_key_gtk, adg);
 
    /* Display the guidance system window. */
    sc_display_console_attach(SC_DISPLAY(w->screen), SC_CONSOLE(adg->console_guidance));
@@ -409,17 +402,10 @@ void _sc_window_auto_defense_shield_init(sc_auto_def_gtk *adg) {
     * just enter_spot.  Can you think of others that would be useful?
     * I can't.  :)
     */
-   #if GTK12_ENABLED
-      gtk_signal_connect_after(GTK_OBJECT(adg->console_shield), "enter-spot",
-                               GTK_SIGNAL_FUNC(_sc_autodef_shield_enter_gtk), adg);
-      gtk_signal_connect_after(GTK_OBJECT(adg->console_shield), "key_press_spot",
-                               GTK_SIGNAL_FUNC(_sc_window_auto_def_key_gtk), adg);
-   #else /* GTK 2.0 */
-      g_signal_connect_after(G_OBJECT(adg->console_shield), "enter-spot",
-                             (GCallback)_sc_autodef_shield_enter_gtk, adg);
-      g_signal_connect_after(G_OBJECT(adg->console_shield), "key_press_spot",
-                             (GCallback)_sc_window_auto_def_key_gtk, adg);
-   #endif /* GTK version? */
+   g_signal_connect_after(G_OBJECT(adg->console_shield), "enter-spot",
+                          (GCallback)_sc_autodef_shield_enter_gtk, adg);
+   g_signal_connect_after(G_OBJECT(adg->console_shield), "key_press_spot",
+                          (GCallback)_sc_window_auto_def_key_gtk, adg);
 
    /* Display the shield selection window. */
    sc_display_console_attach(SC_DISPLAY(w->screen), SC_CONSOLE(adg->console_shield));
@@ -484,13 +470,8 @@ void _sc_window_auto_defense_triggers_init(sc_auto_def_gtk *adg) {
       gtk_widget_set_sensitive(GTK_WIDGET(adg->console_triggers), FALSE);
 
    /* Handle signals; most are handled natively by the toggle... */
-   #if GTK12_ENABLED
-      gtk_signal_connect_after(GTK_OBJECT(adg->console_triggers), "key_press_spot",
-                               GTK_SIGNAL_FUNC(_sc_window_auto_def_key_gtk), adg);
-   #else /* GTK 2.0 */
-      g_signal_connect_after(G_OBJECT(adg->console_triggers), "key_press_spot",
-                             (GCallback)_sc_window_auto_def_key_gtk, adg);
-   #endif /* GTK version? */
+   g_signal_connect_after(G_OBJECT(adg->console_triggers), "key_press_spot",
+                          (GCallback)_sc_window_auto_def_key_gtk, adg);
 
    /* Display the contact triggers window. */
    sc_display_console_attach(SC_DISPLAY(w->screen), SC_CONSOLE(adg->console_triggers));
@@ -570,17 +551,10 @@ void sc_window_auto_defense(sc_window *w_, sc_player *p) {
    sc_active_console_add_spot(SC_ACTIVE_CONSOLE(adg->console_activate), 58, 0, 12, 1, NULL);
 
    /* Connect the signal handlers for EXIT conditions. */
-   #if GTK12_ENABLED
-      gtk_signal_connect_after(GTK_OBJECT(adg->console_activate), "key_press_spot",
-                               GTK_SIGNAL_FUNC(_sc_window_auto_def_key_gtk), adg);
-      gtk_signal_connect_after(GTK_OBJECT(adg->console_activate), "select-spot",
-                               GTK_SIGNAL_FUNC(_sc_window_auto_def_close_gtk), adg);
-   #else /* GTK 2.0 */
-      g_signal_connect_after(G_OBJECT(adg->console_activate), "key_press_spot",
-                             (GCallback)_sc_window_auto_def_key_gtk, adg);
-      g_signal_connect_after(G_OBJECT(adg->console_activate), "select-spot",
-                             (GCallback)_sc_window_auto_def_close_gtk, adg);
-   #endif /* GTK version? */
+   g_signal_connect_after(G_OBJECT(adg->console_activate), "key_press_spot",
+                          (GCallback)_sc_window_auto_def_key_gtk, adg);
+   g_signal_connect_after(G_OBJECT(adg->console_activate), "select-spot",
+                          (GCallback)_sc_window_auto_def_close_gtk, adg);
 
    sc_display_console_attach(SC_DISPLAY(w->screen), SC_CONSOLE(adg->console_activate));
 
