@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/scolor-gtk.c,v 1.9 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/scolor-gtk.c,v 1.11 2009-04-26 17:39:47 jacob Exp $ */
 /*
    
    xscorch - scolor-gtk.c     Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <stdlib.h>
@@ -134,6 +134,3 @@ void sc_colormap_alloc_colors_gtk(sc_window_gtk *w) {
    sc_color_gradient_init(w->c, colors);
 
 }
-
-
-
