@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/sdialog-gtk.h,v 1.4 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/sdialog-gtk.h,v 1.7 2011-07-31 19:05:20 jacob Exp $ */
 /*
    
    xscorch - sdialog-gtk.h    Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __sdialog_gtk_h_included
@@ -30,17 +30,21 @@
 #include <sdialog.h>
 #include <slabel.h>
 #include <sgame/shelp.h>
+#include <sgame/sconfig.h>
 #include <libj/jstr/libjstr.h>
 
 
 /* Tooltips and dialogue helpers */
 static inline GtkWidget *tooltip(sc_window_gtk *w, const char *help, GtkWidget *widget) {
 
-   if(GTK_IS_COMBO(widget)) {
-      gtk_tooltips_set_tip(w->tooltips, GTK_COMBO(widget)->entry, help, help);
-      gtk_tooltips_set_tip(w->tooltips, GTK_COMBO(widget)->list, help, help);
+   /* TOOLTIPS changed from an ass to a mule in GTK 2.12 */
+   if(w->c->options.tooltips) {
+      gtk_widget_set_tooltip_text(widget, help);
+      gtk_widget_set_has_tooltip(widget, TRUE);
+   } else {
+      gtk_widget_set_has_tooltip(widget, FALSE);
    }
-   gtk_tooltips_set_tip(w->tooltips, widget, help, help);
+
    return(widget);
 
 }
@@ -83,4 +87,3 @@ static inline void attach_option(ScDialog *dialog, sc_window_gtk *w, const char
 
 
 #endif /* __sdialog_gtk_h_included */
-
