@@ -1,10 +1,10 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/seconomy-gtk.c,v 1.14 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/seconomy-gtk.c,v 1.17 2011-08-01 00:01:42 jacob Exp $ */
 /*
 
    xscorch - seconomy-gtk.c   Copyright(c) 2000-2003 Justin David Smith
                               Copyright(c) 2003      Jacob Luna Lundberg
    justins(at)chaos2.org      http://chaos2.org/
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Economy configuration dialogue
 
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <assert.h>
@@ -58,7 +58,7 @@ typedef struct _sc_economy_setup_data_gtk {
 
 
 
-static void _sc_economy_setup_apply_gtk(unused ScDialog *dlg,
+static void _sc_economy_setup_apply_gtk(__libj_unused ScDialog *dlg,
                                         sc_economy_setup_data_gtk *setup) {
 
    sc_scoring_info *info;
@@ -153,13 +153,8 @@ void sc_economy_setup_gtk(sc_window_gtk *w) {
    setup.economyidx     = _sc_economy_init_names_gtk(&setup);
 
    dialog = SC_DIALOG(sc_dialog_new("Economy Setup", NULL, confirm | SC_DIALOG_CANCEL));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(dialog), "apply",
-                         GTK_SIGNAL_FUNC(_sc_economy_setup_apply_gtk), &setup);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(dialog), "apply",
-                       (GCallback)_sc_economy_setup_apply_gtk, &setup);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(dialog), "apply",
+                    (GCallback)_sc_economy_setup_apply_gtk, &setup);
 
    attach_option(dialog, w, "Scoring",              sc_link_combo_new(&setup.economyidx, setup.enames), &row);
    attach_option(dialog, w, "Initial Cash",         sc_link_spin_new(&setup.initialcash, 0, SC_ECONOMY_MAX_CASH, SC_ECONOMY_MAX_CASH / 100), &row);
