@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/send-gtk.c,v 1.18 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/send-gtk.c,v 1.20 2009-04-26 17:39:47 jacob Exp $ */
 /*
    
    xscorch - send-gtk.c       Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <math.h>
@@ -79,8 +79,8 @@ static void _sc_window_end_populate_gtk(sc_window_gtk *w, GtkWidget *console) {
 
 
 
-static gboolean _sc_window_end_select_gtk(unused ScActiveConsole *widget,
-                                          unused ScActiveConsoleSpot *spot,
+static gboolean _sc_window_end_select_gtk(__libj_unused ScActiveConsole *widget,
+                                          __libj_unused ScActiveConsoleSpot *spot,
                                           sc_window_gtk *w) {
 
    sc_display_console_detach_all(SC_DISPLAY(w->screen));
@@ -107,13 +107,8 @@ void sc_window_paint_end_round(sc_window *w_) {
 
    sc_console_write_line(SC_CONSOLE(console), 60, 0, "< Continue >");
    sc_active_console_add_spot(SC_ACTIVE_CONSOLE(console), 60, 0, 12, 1, NULL);
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(console), "select_spot", 
-                         GTK_SIGNAL_FUNC(_sc_window_end_select_gtk), w);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(console), "select_spot", 
-                       (GCallback)_sc_window_end_select_gtk, w);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(console), "select_spot", 
+                    (GCallback)_sc_window_end_select_gtk, w);
    
    /* focus on this window */
    gtk_window_set_default(GTK_WINDOW(w->app), GTK_WIDGET(console));
@@ -137,19 +132,11 @@ void sc_window_paint_end_game(sc_window *w_) {
 
    sc_console_write_line(SC_CONSOLE(console), 60, 0, "< Continue >");
    sc_active_console_add_spot(SC_ACTIVE_CONSOLE(console), 60, 0, 12, 1, NULL);
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(console), "select_spot", 
-                         GTK_SIGNAL_FUNC(_sc_window_end_select_gtk), w);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(console), "select_spot", 
-                       (GCallback)_sc_window_end_select_gtk, w);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(console), "select_spot", 
+                    (GCallback)_sc_window_end_select_gtk, w);
 
    /* focus on this window */
    gtk_window_set_default(GTK_WINDOW(w->app), GTK_WIDGET(console));
    gtk_widget_grab_focus(GTK_WIDGET(console));
 
 }
-
-
-
