@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/sfile-gtk.c,v 1.13 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/sfile-gtk.c,v 1.15 2009-04-26 17:39:48 jacob Exp $ */
 /*
    
    xscorch - sfile-gtk.c      Copyright(c) 2001-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sgtk.h>
@@ -44,7 +44,7 @@ typedef struct _sc_file_save {
 
 
 
-static void _sc_config_file_save_apply_gtk(unused ScDialog *dlg, sc_file_save *save) {
+static void _sc_config_file_save_apply_gtk(__libj_unused ScDialog *dlg, sc_file_save *save) {
 
    char buf[0x1000];
       
@@ -71,13 +71,8 @@ void sc_config_file_save_gtk(sc_window_gtk *w) {
    strcopyb(save.name, w->c->cfreg->filename, sizeof(save.name));
    
    dialog = SC_DIALOG(sc_dialog_new("Save Options As ...", NULL, SC_DIALOG_OK | SC_DIALOG_CANCEL));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(dialog), "apply",
-                         GTK_SIGNAL_FUNC(_sc_config_file_save_apply_gtk), &save);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(dialog), "apply",
-                       (GCallback)_sc_config_file_save_apply_gtk, &save);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(dialog), "apply",
+                    (GCallback)_sc_config_file_save_apply_gtk, &save);
 
    attach_option_help(dialog, w, "Save options in file", 
                       "Specify the name of a file to save your user configuration to.", 
@@ -86,6 +81,3 @@ void sc_config_file_save_gtk(sc_window_gtk *w) {
    sc_dialog_run(dialog);
 
 }
-
-
-
