@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/sgraphics-gtk.c,v 1.12 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/sgraphics-gtk.c,v 1.14 2009-04-26 17:39:48 jacob Exp $ */
 /*
    
    xscorch - sgraphics-gtk.c  Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sgtk.h>
@@ -51,7 +51,7 @@ typedef struct _sc_graphics_setup_data_gtk {
 
 
 
-static void _sc_graphics_setup_apply_gtk(unused ScDialog *dlg,
+static void _sc_graphics_setup_apply_gtk(__libj_unused ScDialog *dlg,
                                          sc_graphics_setup_data_gtk *setup) {
 
    sc_config *c = setup->c;
@@ -97,14 +97,6 @@ static void _sc_graphics_setup_apply_gtk(unused ScDialog *dlg,
 
 
 
-static void _sc_font_gtk(unused GtkWidget *widget, sc_window_gtk *w) {
-
-   sc_font_gtk(w);
-
-}
-
-
-
 void sc_graphics_setup_gtk(sc_window_gtk *w) {
 
    sc_config *c = w->c;
@@ -123,13 +115,8 @@ void sc_graphics_setup_gtk(sc_window_gtk *w) {
    setup.gfxcompfast = c->graphics.gfxcompfast;
 
    dialog = SC_DIALOG(sc_dialog_new("Graphics Setup", NULL, confirm | SC_DIALOG_CANCEL));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(dialog), "apply",
-                         GTK_SIGNAL_FUNC(_sc_graphics_setup_apply_gtk), &setup);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(dialog), "apply",
-                       (GCallback)_sc_graphics_setup_apply_gtk, &setup);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(dialog), "apply",
+                    (GCallback)_sc_graphics_setup_apply_gtk, &setup);
 
    attach_option(dialog, w, "Screen Width",        sc_link_spin_new(&setup.fieldwidth, SC_MIN_FIELD_WIDTH, SC_MAX_FIELD_WIDTH, 8), &row);
    attach_option(dialog, w, "Screen Height",       sc_link_spin_new(&setup.fieldheight, SC_MIN_FIELD_HEIGHT, SC_MAX_FIELD_HEIGHT, 8), &row);
@@ -139,13 +126,7 @@ void sc_graphics_setup_gtk(sc_window_gtk *w) {
    attach_option(dialog, w, "Computers Are Fast",  sc_link_check_new(&setup.gfxcompfast), &row);
    
    button = gtk_button_new_with_label(" Setup Fonts ");
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                         GTK_SIGNAL_FUNC(_sc_font_gtk), w);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(button), "clicked",
-                       (GCallback)_sc_font_gtk, w);
-   #endif /* GTK version? */
+   g_signal_connect_swapped(G_OBJECT(button), "clicked", G_CALLBACK(sc_font_gtk), w);  /*swapped args for sc_font_gtk */
    sc_dialog_grid_attach(dialog, button, row++, 1);
 
    sc_dialog_run(dialog);
