@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/simage-gtk.c,v 1.5 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/simage-gtk.c,v 1.7 2009-04-26 17:39:48 jacob Exp $ */
 /*
    
    xscorch - simage-gtk.c     Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sgtk.h>
@@ -62,6 +62,3 @@ void sc_pixmap_copy_gtk(GdkPixmap *dest, GdkGC *gc, GdkPixmap *src, GdkBitmap *m
    gdk_gc_set_clip_mask(gc, NULL);
    
 }
-
-
-
