@@ -1,10 +1,10 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/sinventory-gtk.c,v 1.43 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/sinventory-gtk.c,v 1.46 2011-08-01 00:01:42 jacob Exp $ */
 /*
 
    xscorch - sinventory-gtk.c Copyright(c) 2000-2004 Justin David Smith
                               Copyright(c) 2001-2004 Jacob Luna Lundberg
    justins(at)chaos2.org      http://chaos2.org/
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Player configuration dialogue
 
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sgtk.h>
@@ -159,7 +159,7 @@ static void _sc_inventory_accessory_paint_gtk(sc_inventory_gtk *inv) {
 
 
 
-static gboolean _sc_inventory_weapon_key_gtk(unused ScActiveConsole *cons,
+static gboolean _sc_inventory_weapon_key_gtk(__libj_unused ScActiveConsole *cons,
                                              ScActiveConsoleSpot *spot,
                                              GdkEventKey *event, sc_inventory_gtk *inv) {
 /* sc_inventory_weapon_key_gtk
@@ -192,7 +192,7 @@ static gboolean _sc_inventory_weapon_key_gtk(unused ScActiveConsole *cons,
 
 
 
-static gboolean _sc_inventory_accessory_key_gtk(unused ScActiveConsole *cons,
+static gboolean _sc_inventory_accessory_key_gtk(__libj_unused ScActiveConsole *cons,
                                                 ScActiveConsoleSpot *spot,
                                                 GdkEventKey *event, sc_inventory_gtk *inv) {
 /* sc_inventory_accessory_key_gtk
@@ -225,7 +225,7 @@ static gboolean _sc_inventory_accessory_key_gtk(unused ScActiveConsole *cons,
 
 
 
-static gboolean _sc_inventory_weapon_button_gtk(unused ScActiveConsole *cons,
+static gboolean _sc_inventory_weapon_button_gtk(__libj_unused ScActiveConsole *cons,
                                                 ScActiveConsoleSpot *spot,
                                                 GdkEventButton *event, sc_inventory_gtk *inv) {
 /* sc_inventory_weapon_button_gtk
@@ -259,7 +259,7 @@ static gboolean _sc_inventory_weapon_button_gtk(unused ScActiveConsole *cons,
 
 
 
-static gboolean _sc_inventory_accessory_button_gtk(unused ScActiveConsole *cons,
+static gboolean _sc_inventory_accessory_button_gtk(__libj_unused ScActiveConsole *cons,
                                                    ScActiveConsoleSpot *spot,
                                                    GdkEventButton *event, sc_inventory_gtk *inv) {
 /* sc_inventory_accessory_button_gtk
@@ -293,7 +293,7 @@ static gboolean _sc_inventory_accessory_button_gtk(unused ScActiveConsole *cons,
 
 
 
-static gboolean _sc_inventory_weapon_enter_gtk(unused ScActiveConsole *cons,
+static gboolean _sc_inventory_weapon_enter_gtk(__libj_unused ScActiveConsole *cons,
                                                ScActiveConsoleSpot *spot,
                                                sc_inventory_gtk *inv) {
 /* sc_inventory_weapon_enter_gtk */
@@ -315,7 +315,7 @@ static gboolean _sc_inventory_weapon_enter_gtk(unused ScActiveConsole *cons,
 
 
 
-static gboolean _sc_inventory_accessory_enter_gtk(unused ScActiveConsole *cons,
+static gboolean _sc_inventory_accessory_enter_gtk(__libj_unused ScActiveConsole *cons,
                                                   ScActiveConsoleSpot *spot,
                                                   sc_inventory_gtk *inv) {
 /* sc_inventory_accessory_enter_gtk */
@@ -337,8 +337,8 @@ static gboolean _sc_inventory_accessory_enter_gtk(unused ScActiveConsole *cons,
 
 
 
-static gboolean _sc_inventory_info_leave_gtk(unused ScActiveConsole *cons,
-                                             unused ScActiveConsoleSpot *spot,
+static gboolean _sc_inventory_info_leave_gtk(__libj_unused ScActiveConsole *cons,
+                                             __libj_unused ScActiveConsoleSpot *spot,
                                              sc_inventory_gtk *inv) {
 /* sc_inventory_info_leave_gtk */
 
@@ -351,8 +351,8 @@ static gboolean _sc_inventory_info_leave_gtk(unused ScActiveConsole *cons,
 
 
 
-static gboolean _sc_inventory_continue_gtk(unused ScActiveConsole *cons,
-                                           unused ScActiveConsoleSpot *spot,
+static gboolean _sc_inventory_continue_gtk(__libj_unused ScActiveConsole *cons,
+                                           __libj_unused ScActiveConsoleSpot *spot,
                                            sc_inventory_gtk *inv) {
 /* sc_inventory_continue_gtk
    User has closed the inventory window. */
@@ -417,25 +417,14 @@ static void _sc_inventory_create_gtk(sc_window_gtk *w, sc_player *p) {
 
    /* Hook up the various callbacks and add hotspots for
       each weapon which is in the panel. */
-   #if GTK12_ENABLED
-      gtk_signal_connect_after(GTK_OBJECT(inv->weaponpane), "key_press_spot",
-                               GTK_SIGNAL_FUNC(_sc_inventory_weapon_key_gtk), inv);
-      gtk_signal_connect_after(GTK_OBJECT(inv->weaponpane), "button_press_spot",
-                               GTK_SIGNAL_FUNC(_sc_inventory_weapon_button_gtk), inv);
-      gtk_signal_connect_after(GTK_OBJECT(inv->weaponpane), "enter_spot",
-                               GTK_SIGNAL_FUNC(_sc_inventory_weapon_enter_gtk), inv);
-      gtk_signal_connect_after(GTK_OBJECT(inv->weaponpane), "leave_spot",
-                               GTK_SIGNAL_FUNC(_sc_inventory_info_leave_gtk), inv);
-   #else /* GTK 2.0 */
-      g_signal_connect_after(G_OBJECT(inv->weaponpane), "key_press_spot",
-                             (GCallback)_sc_inventory_weapon_key_gtk, inv);
-      g_signal_connect_after(G_OBJECT(inv->weaponpane), "button_press_spot",
-                             (GCallback)_sc_inventory_weapon_button_gtk, inv);
-      g_signal_connect_after(G_OBJECT(inv->weaponpane), "enter_spot",
-                             (GCallback)_sc_inventory_weapon_enter_gtk, inv);
-      g_signal_connect_after(G_OBJECT(inv->weaponpane), "leave_spot",
-                             (GCallback)_sc_inventory_info_leave_gtk, inv);
-   #endif /* GTK version? */
+   g_signal_connect_after(G_OBJECT(inv->weaponpane), "key_press_spot",
+                          (GCallback)_sc_inventory_weapon_key_gtk, inv);
+   g_signal_connect_after(G_OBJECT(inv->weaponpane), "button_press_spot",
+                          (GCallback)_sc_inventory_weapon_button_gtk, inv);
+   g_signal_connect_after(G_OBJECT(inv->weaponpane), "enter_spot",
+                          (GCallback)_sc_inventory_weapon_enter_gtk, inv);
+   g_signal_connect_after(G_OBJECT(inv->weaponpane), "leave_spot",
+                          (GCallback)_sc_inventory_info_leave_gtk, inv);
    sc_display_console_attach(SC_DISPLAY(w->screen), SC_CONSOLE(inv->weaponpane));
    for(i = 0; i < wpcount; ++i) {
       sc_active_console_add_row_spot(SC_ACTIVE_CONSOLE(inv->weaponpane), i, wpinfo);
@@ -444,25 +433,14 @@ static void _sc_inventory_create_gtk(sc_window_gtk *w, sc_player *p) {
 
    /* Hook up the various callbacks and add hotspots for
       each accessory which is in the panel. */
-   #if GTK12_ENABLED
-      gtk_signal_connect_after(GTK_OBJECT(inv->accessorypane), "key_press_spot",
-                               GTK_SIGNAL_FUNC(_sc_inventory_accessory_key_gtk), inv);
-      gtk_signal_connect_after(GTK_OBJECT(inv->accessorypane), "button_press_spot",
-                               GTK_SIGNAL_FUNC(_sc_inventory_accessory_button_gtk), inv);
-      gtk_signal_connect_after(GTK_OBJECT(inv->accessorypane), "enter_spot",
-                               GTK_SIGNAL_FUNC(_sc_inventory_accessory_enter_gtk), inv);
-      gtk_signal_connect_after(GTK_OBJECT(inv->accessorypane), "leave_spot",
-                               GTK_SIGNAL_FUNC(_sc_inventory_info_leave_gtk), inv);
-   #else /* GTK 2.0 */
-      g_signal_connect_after(G_OBJECT(inv->accessorypane), "key_press_spot",
-                             (GCallback)_sc_inventory_accessory_key_gtk, inv);
-      g_signal_connect_after(G_OBJECT(inv->accessorypane), "button_press_spot",
-                             (GCallback)_sc_inventory_accessory_button_gtk, inv);
-      g_signal_connect_after(G_OBJECT(inv->accessorypane), "enter_spot",
-                             (GCallback)_sc_inventory_accessory_enter_gtk, inv);
-      g_signal_connect_after(G_OBJECT(inv->accessorypane), "leave_spot",
-                             (GCallback)_sc_inventory_info_leave_gtk, inv);
-   #endif /* GTK version? */
+   g_signal_connect_after(G_OBJECT(inv->accessorypane), "key_press_spot",
+                          (GCallback)_sc_inventory_accessory_key_gtk, inv);
+   g_signal_connect_after(G_OBJECT(inv->accessorypane), "button_press_spot",
+                          (GCallback)_sc_inventory_accessory_button_gtk, inv);
+   g_signal_connect_after(G_OBJECT(inv->accessorypane), "enter_spot",
+                          (GCallback)_sc_inventory_accessory_enter_gtk, inv);
+   g_signal_connect_after(G_OBJECT(inv->accessorypane), "leave_spot",
+                          (GCallback)_sc_inventory_info_leave_gtk, inv);
    sc_display_console_attach(SC_DISPLAY(w->screen), SC_CONSOLE(inv->accessorypane));
    for(i = 0; i < account; ++i) {
       sc_active_console_add_row_spot(SC_ACTIVE_CONSOLE(inv->accessorypane), i, acinfo);
@@ -474,13 +452,8 @@ static void _sc_inventory_create_gtk(sc_window_gtk *w, sc_player *p) {
    sc_console_set_foreground(SC_CONSOLE(inv->infopane), &w->colormap->pcolors[p->index]);
    sc_console_write_line(SC_CONSOLE(inv->infopane), 70, 1, "< Continue >");
    sc_active_console_add_spot(SC_ACTIVE_CONSOLE(inv->infopane), 70, 1, 12, 1, NULL);
-   #if GTK12_ENABLED
-      gtk_signal_connect_after(GTK_OBJECT(inv->infopane), "select_spot",
-                               GTK_SIGNAL_FUNC(_sc_inventory_continue_gtk), inv);
-   #else /* GTK 2.0 */
-      g_signal_connect_after(G_OBJECT(inv->infopane), "select_spot",
-                             (GCallback)_sc_inventory_continue_gtk, inv);
-   #endif /* GTK version? */
+   g_signal_connect_after(G_OBJECT(inv->infopane), "select_spot",
+                          (GCallback)_sc_inventory_continue_gtk, inv);
 
    /* Paint every pane. */
    _sc_inventory_weapon_paint_gtk(inv);
