@@ -1,10 +1,10 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/slottery-gtk.c,v 1.12 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/slottery-gtk.c,v 1.15 2011-08-01 00:01:42 jacob Exp $ */
 /*
 
    xscorch - slottery-gtk.c   Copyright(c) 2001-2003 Justin David Smith
                               Copyright(c) 2001-2003 Jacob Luna Lundberg
    justins(at)chaos2.org      http://chaos2.org/
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Lottery results screen
 
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <math.h>
@@ -47,8 +47,8 @@
 
 
 
-static gboolean _sc_window_lottery_close_gtk(unused GtkWidget *widget,
-                                             unused ScActiveConsoleSpot *spot,
+static gboolean _sc_window_lottery_close_gtk(__libj_unused GtkWidget *widget,
+                                             __libj_unused ScActiveConsoleSpot *spot,
                                              sc_window_gtk *w) {
 /* _sc_window_lottery_close_gtk
    Advance on to the round proper. */
@@ -61,8 +61,8 @@ static gboolean _sc_window_lottery_close_gtk(unused GtkWidget *widget,
 
 
 
-static gboolean _sc_window_lottery_key_gtk(unused GtkWidget *widget,
-                                           unused ScActiveConsoleSpot *spot,
+static gboolean _sc_window_lottery_key_gtk(__libj_unused GtkWidget *widget,
+                                           __libj_unused ScActiveConsoleSpot *spot,
                                            GdkEventKey *key, sc_window_gtk *w) {
 /* _sc_window_lottery_key_gtk
    Handle keystrokes.  Advance on to the round proper. */
@@ -124,17 +124,10 @@ void sc_window_lottery_result(sc_window *w_, bool showstake) {
    sc_active_console_add_spot(SC_ACTIVE_CONSOLE(console), 27, 6, 9, 1, NULL);
 
    /* Connect the exit methods. */
-   #if GTK12_ENABLED
-      gtk_signal_connect_after(GTK_OBJECT(console), "key_press_spot", 
-                               GTK_SIGNAL_FUNC(_sc_window_lottery_key_gtk), w);
-      gtk_signal_connect_after(GTK_OBJECT(console), "select-spot", 
-                               GTK_SIGNAL_FUNC(_sc_window_lottery_close_gtk), w);
-   #else /* GTK 2.0 */
-      g_signal_connect_after(G_OBJECT(console), "key_press_spot", 
-                             (GCallback)_sc_window_lottery_key_gtk, w);
-      g_signal_connect_after(G_OBJECT(console), "select-spot", 
-                             (GCallback)_sc_window_lottery_close_gtk, w);
-   #endif /* GTK version? */
+   g_signal_connect_after(G_OBJECT(console), "key_press_spot", 
+                          (GCallback)_sc_window_lottery_key_gtk, w);
+   g_signal_connect_after(G_OBJECT(console), "select-spot", 
+                          (GCallback)_sc_window_lottery_close_gtk, w);
 
    /* focus on this window */
    gtk_window_set_default(GTK_WINDOW(w->app), GTK_WIDGET(console));
