@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/smainmenu-gtk.c,v 1.21 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/smainmenu-gtk.c,v 1.23 2009-04-26 17:39:49 jacob Exp $ */
 /*
    
    xscorch - smainmenu-gtk.c  Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sgtk.h>
@@ -118,7 +118,7 @@ static gboolean _sc_main_menu_action_gtk(sc_window_gtk *w, gint row) {
 
 
 
-static gboolean _sc_main_menu_select_gtk(unused ScActiveConsole *cons,
+static gboolean _sc_main_menu_select_gtk(__libj_unused ScActiveConsole *cons,
                                          ScActiveConsoleSpot *spot,
                                          sc_window_gtk *w) {
 
@@ -176,13 +176,8 @@ void sc_window_main_menu(sc_window *w_) {
    }
 
    /* Must be connected after default handler is run */
-   #if GTK12_ENABLED
-      gtk_signal_connect_after(GTK_OBJECT(console), "select_spot",
-                               GTK_SIGNAL_FUNC(_sc_main_menu_select_gtk), w);
-   #else /* GTK 2.0 */
-      g_signal_connect_after(G_OBJECT(console), "select_spot",
-                             (GCallback)_sc_main_menu_select_gtk, w);
-   #endif /* GTK version? */
+   g_signal_connect_after(G_OBJECT(console), "select_spot",
+                          (GCallback)_sc_main_menu_select_gtk, w);
    g_object_set_data(G_OBJECT(console), "user_data", w);
    sc_display_console_attach(SC_DISPLAY(w->screen), SC_CONSOLE(console));
 
