@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/snet-gtk.c,v 1.16 2004/03/25 04:41:13 jacob Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/snet-gtk.c,v 1.18 2009-04-26 17:39:49 jacob Exp $ */
 /*
    
    xscorch - snet-gtk.c       Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sgtk.h>
@@ -50,7 +50,7 @@ typedef struct _sc_chat {
 /* TEMP - Serious revisions needed in this file for GTK 2.0 support. */
 #if GTK12_ENABLED
 
-static void _sc_chat_window_delete(unused GtkWidget *window, sc_chat *config) {
+static void _sc_chat_window_delete(__libj_unused GtkWidget *window, sc_chat *config) {
 
    sc_window_gtk *w = (sc_window_gtk *)config->c->window;
    w->chatbox = NULL;
@@ -58,7 +58,7 @@ static void _sc_chat_window_delete(unused GtkWidget *window, sc_chat *config) {
 }
 
 
-static void _sc_chat_send_gtk(unused GtkWidget *send, sc_chat *config) {
+static void _sc_chat_send_gtk(__libj_unused GtkWidget *send, sc_chat *config) {
 
    if(config->c->client != NULL) {
       const char *text = gtk_entry_get_text(GTK_ENTRY(config->entry));
@@ -105,13 +105,8 @@ void sc_chat_window_gtk(sc_window_gtk *w) {
    config.c = w->c;
 
    dialog = SC_DIALOG(sc_dialog_new("Chat", NULL, SC_DIALOG_CLOSE | SC_DIALOG_NONMODAL));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(dialog), "destroy",
-                         GTK_SIGNAL_FUNC(_sc_chat_window_delete), &config);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(dialog), "destroy",
-                       (GCallback)_sc_chat_window_delete, &config);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(dialog), "destroy",
+                    (GCallback)_sc_chat_window_delete, &config);
 
    view = gtk_scrolled_window_new(NULL, NULL);
    gtk_widget_set_usize(view, 550, 100);
@@ -124,24 +119,14 @@ void sc_chat_window_gtk(sc_window_gtk *w) {
 
    widget = sc_link_entry_new(input, SC_NET_INPUT_SIZE);
    gtk_widget_set_usize(widget, 450, 0);
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(widget), "key-press-event",
-                         GTK_SIGNAL_FUNC(_sc_chat_send_key_gtk), &config);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(widget), "key-press-event",
-                       (GCallback)_sc_chat_send_key_gtk, &config);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(widget), "key-press-event",
+                    (GCallback)_sc_chat_send_key_gtk, &config);
    gtk_table_attach(GTK_TABLE(dialog->grid), widget, 0, 1, 1, 2, GTK_FILL | GTK_EXPAND, GTK_FILL, 2, 2);
    config.entry = widget;
 
    widget = gtk_button_new_with_label(" Send ");
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(widget), "clicked",
-                         GTK_SIGNAL_FUNC(_sc_chat_send_gtk), &config);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(widget), "clicked",
-                       (GCallback)_sc_chat_send_gtk, &config);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(widget), "clicked",
+                    (GCallback)_sc_chat_send_gtk, &config);
    gtk_table_attach(GTK_TABLE(dialog->grid), widget, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 2, 2);
 
    sc_dialog_run(dialog);
@@ -161,7 +146,7 @@ void sc_chat_window_update(sc_window *_w, const char *msg) {
 void sc_chat_window_gtk(sc_window_gtk *w) {
 
    /* GtkTextView (GTK2) support not implemented yet for chat window. */
-   sc_dialog_message("Text viewer unimplemented", "Sorry, the text viewer has not been implemented yet.");
+   sc_dialog_message("Text viewer unimplemented", "Sorry, the GTK 2 text viewer has not been implemented yet.");
 
 }
       
@@ -176,7 +161,7 @@ typedef struct _sc_server_config {
 
 
 
-static void _sc_network_server_apply_gtk(unused ScDialog *dlg, sc_server_config *config) {
+static void _sc_network_server_apply_gtk(__libj_unused ScDialog *dlg, sc_server_config *config) {
 
    int portnum;
    
@@ -222,13 +207,8 @@ void sc_network_server_gtk(sc_window_gtk *w) {
    sbprintf(config.port, sizeof(config.port), "%d", SC_NET_DEFAULT_PORT);
    
    dialog = SC_DIALOG(sc_dialog_new("Create server", NULL, SC_DIALOG_OK | SC_DIALOG_CANCEL));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(dialog), "apply",
-                         GTK_SIGNAL_FUNC(_sc_network_server_apply_gtk), &config);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(dialog), "apply",
-                       (GCallback)_sc_network_server_apply_gtk, &config);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(dialog), "apply",
+                    (GCallback)_sc_network_server_apply_gtk, &config);
 
    attach_option_help(dialog, w, "Player name",  SC_PLAYER_HELP, sc_link_entry_new(config.name, SC_NET_NAME_SIZE), &row);
    attach_option_help(dialog, w, "Listen on port", SC_PORT_HELP, sc_link_entry_new(config.port, SC_NET_INPUT_SIZE), &row);
@@ -248,7 +228,7 @@ typedef struct _sc_client_config {
 
 
 
-static void _sc_network_client_apply_gtk(unused ScDialog *dlg, sc_client_config *config) {
+static void _sc_network_client_apply_gtk(__libj_unused ScDialog *dlg, sc_client_config *config) {
 
    int portnum;
    
@@ -289,13 +269,8 @@ void sc_network_client_gtk(sc_window_gtk *w) {
    strcopyb(config.server, SC_NET_DEFAULT_SERVER, sizeof(config.server));
    
    dialog = SC_DIALOG(sc_dialog_new("Connect as client", NULL, SC_DIALOG_OK | SC_DIALOG_CANCEL));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(dialog), "apply",
-                         GTK_SIGNAL_FUNC(_sc_network_client_apply_gtk), &config);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(dialog), "apply",
-                       (GCallback)_sc_network_client_apply_gtk, &config);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(dialog), "apply",
+                    (GCallback)_sc_network_client_apply_gtk, &config);
 
    attach_option_help(dialog, w, "Player name",  SC_PLAYER_HELP, sc_link_entry_new(config.name, SC_NET_NAME_SIZE), &row);
    attach_option_help(dialog, w, "Server name",  SC_SERVER_HELP, sc_link_entry_new(config.server, SC_NET_INPUT_SIZE), &row);
