@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/soptions-gtk.c,v 1.15 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/soptions-gtk.c,v 1.19 2011-07-31 20:06:43 jacob Exp $ */
 /*
    
    xscorch - soptions-gtk.c   Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sgtk.h>
@@ -51,7 +51,7 @@ typedef struct _sc_options_setup_data_gtk {
 
 
 
-static void _sc_options_setup_apply_gtk(unused ScDialog *dlg, sc_options_setup_data_gtk *setup) {
+static void _sc_options_setup_apply_gtk(__libj_unused ScDialog *dlg, sc_options_setup_data_gtk *setup) {
 
    sc_config_options *co = setup->co;
    sc_window_gtk *w = (sc_window_gtk *)setup->c->window;
@@ -71,10 +71,15 @@ static void _sc_options_setup_apply_gtk(unused ScDialog *dlg, sc_options_setup_d
    
    /* Reconfigure the statusbar */
    if(oldextstatus != co->extstatus) sc_status_setup(setup->c->window);
+
+   /* TEMP: I can't find a way to do this with GTK2...
+    * Probably tooltips won't appear if they're off until you enable them and restart xscorch.
+    *
    if(oldtooltips != co->tooltips) {
-      if(co->tooltips) gtk_tooltips_enable(w->tooltips);
-      else             gtk_tooltips_disable(w->tooltips);
+      if(co->tooltips) gtk_tooltips_enable(w);
+      else             gtk_tooltips_disable(w);
    }
+    */
       
    #if USE_NETWORK
    if(SC_NETWORK_SERVER(setup->c)) sc_net_server_send_config(setup->c, setup->c->server);
@@ -108,26 +113,18 @@ void sc_options_setup_gtk(sc_window_gtk *w) {
    while(sc_config_talk_types()[setup.talkidx] != co->talk)  ++setup.talkidx;
 
    dialog = SC_DIALOG(sc_dialog_new("Options Setup", NULL, confirm | SC_DIALOG_CANCEL));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(dialog), "apply", 
-                         GTK_SIGNAL_FUNC(_sc_options_setup_apply_gtk), &setup);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(dialog), "apply",
-                       (GCallback)_sc_options_setup_apply_gtk, &setup);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(dialog), "apply",
+                    (GCallback)_sc_options_setup_apply_gtk, &setup);
 
-   attach_option(dialog, w, "Mode",             sc_link_combo_new(&setup.modeidx, sc_config_mode_names()), &row);
-   attach_option(dialog, w, "N/A:  Teams",      sc_link_combo_new(&setup.teamidx, sc_config_team_names()), &row);
-   attach_option(dialog, w, "Order",            sc_link_combo_new(&setup.orderidx, sc_config_order_names()), &row);
-   attach_option(dialog, w, "Talk Mode",        sc_link_combo_new(&setup.talkidx, sc_config_talk_names()), &row);
-   attach_option(dialog, w, "Talk Probability", sc_link_spin_new(&setup.talkprob, 0, 100, 1), &row);
-   attach_option(dialog, w, "Extended Status",  sc_link_check_new(&setup.extstatus), &row);
-   attach_option(dialog, w, "Tooltips",         sc_link_check_new(&setup.tooltips), &row);
-   attach_option(dialog, w, "Interleaved Tracking",   sc_link_check_new(&setup.interleave), &row);
+   attach_option(dialog, w, "Mode",                 sc_link_combo_new(&setup.modeidx, sc_config_mode_names()), &row);
+   attach_option(dialog, w, "N/A:  Teams",          sc_link_combo_new(&setup.teamidx, sc_config_team_names()), &row);
+   attach_option(dialog, w, "Order",                sc_link_combo_new(&setup.orderidx, sc_config_order_names()), &row);
+   attach_option(dialog, w, "Talk Mode",            sc_link_combo_new(&setup.talkidx, sc_config_talk_names()), &row);
+   attach_option(dialog, w, "Talk Probability",     sc_link_spin_new(&setup.talkprob, 0, 100, 1), &row);
+   attach_option(dialog, w, "Extended Status",      sc_link_check_new(&setup.extstatus), &row);
+   attach_option(dialog, w, "Tooltips",             sc_link_check_new(&setup.tooltips), &row);
+   attach_option(dialog, w, "Interleaved Tracking", sc_link_check_new(&setup.interleave), &row);
    
    sc_dialog_run(dialog);
 
 }
-
-
-
