@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/sphysics-gtk.c,v 1.12 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/sphysics-gtk.c,v 1.14 2009-04-26 17:39:49 jacob Exp $ */
 /*
    
    xscorch - sphysics-gtk.c   Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sgtk.h>
@@ -53,7 +53,7 @@ typedef struct _sc_physics_setup_data_gtk {
 
 
 
-static void _sc_physics_setup_apply_gtk(unused ScDialog *dlg,
+static void _sc_physics_setup_apply_gtk(__libj_unused ScDialog *dlg,
                                         sc_physics_setup_data_gtk *setup) {
 
    sc_physics *ph = setup->ph;
@@ -98,13 +98,8 @@ void sc_physics_setup_gtk(sc_window_gtk *w) {
    while(ph->walls != sc_physics_wall_types()[setup.wallidx]) ++setup.wallidx;
 
    dialog = SC_DIALOG(sc_dialog_new("Physics Setup", NULL, confirm | SC_DIALOG_CANCEL));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(dialog), "apply",
-                         GTK_SIGNAL_FUNC(_sc_physics_setup_apply_gtk), &setup);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(dialog), "apply",
-                       (GCallback)_sc_physics_setup_apply_gtk, &setup);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(dialog), "apply",
+                    (GCallback)_sc_physics_setup_apply_gtk, &setup);
 
    attach_option(dialog, w, "N/A:  Air Viscosity", sc_link_spinf_new(&setup.airviscosity, 0, SC_PHYSICS_VISCOUS_MAX, 0.001), &row);
    attach_option(dialog, w, "Gravity",             sc_link_spinf_new(&setup.gravity, 0, SC_PHYSICS_GRAVITY_MAX, 0.01), &row);
