@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/sstatus-gtk.c,v 1.35 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/sstatus-gtk.c,v 1.38 2009-04-26 17:39:50 jacob Exp $ */
 /*
 
    xscorch - sstatus-gtk.c    Copyright(c) 2000-2004 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <assert.h>
@@ -101,7 +101,7 @@ static void _sc_status_write_line(const sc_window_gtk *w, const sc_player *p, in
 
 
 
-static gboolean _sc_status_activate_item(unused GtkWidget *widget,
+static gboolean _sc_status_activate_item(__libj_unused GtkWidget *widget,
                                          ScActiveConsoleSpot *spot,
                                          sc_window_gtk *w) {
 
@@ -111,7 +111,7 @@ static gboolean _sc_status_activate_item(unused GtkWidget *widget,
    if(!SC_STATE_IS_ENABLED(w->c->game) || SC_STATE_IS_PAUSE(w->c->game)) return(FALSE);
 
    /* What action to perform? */
-   switch((int)spot->data) {
+   switch((long)spot->data) {
       case SC_STATUS_TOGGLE_WEAPON:
          sc_player_advance_weapon(w->c, curplayer, 1);
          return(TRUE);
@@ -334,13 +334,8 @@ void sc_status_resume(sc_window *_w) {
 
 void sc_status_configure_gtk(sc_window_gtk *w) {
 
-   #if GTK12_ENABLED
-      gtk_signal_connect_after(GTK_OBJECT(w->status), "select-spot",
-                               GTK_SIGNAL_FUNC(_sc_status_activate_item), w);
-   #else /* GTK 2.0 */
-      g_signal_connect_after(G_OBJECT(w->status), "select-spot",
-                             (GCallback)_sc_status_activate_item, w);
-   #endif /* GTK version? */
+   g_signal_connect_after(G_OBJECT(w->status), "select-spot",
+                          (GCallback)_sc_status_activate_item, w);
    sc_active_console_set_allow_keyboard(SC_ACTIVE_CONSOLE(w->status), FALSE);
    _sc_status_reset_state(w, FALSE);
 
