@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/ssystem-gtk.c,v 1.10 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/ssystem-gtk.c,v 1.12 2009-04-26 17:39:50 jacob Exp $ */
 /*
 
    xscorch - ssystem-gtk.c    Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <ssystem-gtk.h>
@@ -45,7 +45,7 @@ typedef struct _sc_system_menu_data_gtk {
 
 
 
-static void _sc_system_menu_apply_gtk(unused ScDialog *dlg,
+static void _sc_system_menu_apply_gtk(__libj_unused ScDialog *dlg,
                                       sc_system_menu_data_gtk *setup) {
 
    setup->c->graphics.gfxanimate = setup->gfxanimate;
@@ -56,8 +56,8 @@ static void _sc_system_menu_apply_gtk(unused ScDialog *dlg,
 
 
 
-static void _sc_system_retreat_gtk(unused GtkWidget *button,
-                                   unused sc_system_menu_data_gtk *setup) {
+static void _sc_system_retreat_gtk(__libj_unused GtkWidget *button,
+                                   __libj_unused sc_system_menu_data_gtk *setup) {
 
    sc_dialog_error("Sorry, not implemented");
 
@@ -65,7 +65,7 @@ static void _sc_system_retreat_gtk(unused GtkWidget *button,
 
 
 
-static void _sc_system_resign_gtk(unused GtkWidget *button,
+static void _sc_system_resign_gtk(__libj_unused GtkWidget *button,
                                   sc_system_menu_data_gtk *setup) {
 
    #if USE_NETWORK
@@ -86,7 +86,7 @@ static void _sc_system_resign_gtk(unused GtkWidget *button,
 
 
 
-static void _sc_system_mass_kill_gtk(unused GtkWidget *button,
+static void _sc_system_mass_kill_gtk(__libj_unused GtkWidget *button,
                                      sc_system_menu_data_gtk *setup) {
 
    #if USE_NETWORK
@@ -108,7 +108,7 @@ static void _sc_system_mass_kill_gtk(unused GtkWidget *button,
 
 
 
-static void _sc_system_erase_smoke_gtk(unused GtkWidget *button,
+static void _sc_system_erase_smoke_gtk(__libj_unused GtkWidget *button,
                                        sc_system_menu_data_gtk *setup) {
 
    sc_land_clear_smoke(setup->c, setup->c->land);
@@ -117,7 +117,7 @@ static void _sc_system_erase_smoke_gtk(unused GtkWidget *button,
 
 
 
-static void _sc_system_sound_gtk(unused GtkWidget *button,
+static void _sc_system_sound_gtk(__libj_unused GtkWidget *button,
                                  sc_system_menu_data_gtk *setup) {
 
    sc_sound_setup_gtk((sc_window_gtk *)setup->c->window);
@@ -141,13 +141,8 @@ void sc_system_menu_gtk(sc_window_gtk *w) {
    setup.gfxcompfast    = c->graphics.gfxcompfast;
 
    dialog = SC_DIALOG(sc_dialog_new("System Menu", NULL, SC_DIALOG_OK | SC_DIALOG_CANCEL));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(dialog), "apply",
-                         GTK_SIGNAL_FUNC(_sc_system_menu_apply_gtk), &setup);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(dialog), "apply",
-                       (GCallback)_sc_system_menu_apply_gtk, &setup);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(dialog), "apply",
+                    (GCallback)_sc_system_menu_apply_gtk, &setup);
 
    attach_option(dialog, w, "Animation",           sc_link_check_new(&setup.gfxanimate), &row);
    attach_option(dialog, w, "Graphics Are Fast",   sc_link_check_new(&setup.gfxfast), &row);
@@ -155,57 +150,32 @@ void sc_system_menu_gtk(sc_window_gtk *w) {
 
    sc_help_text(help, sizeof(help), "Mass Kill");
    button = tooltip(w, help, gtk_button_new_with_label(" Mass Kill "));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                         GTK_SIGNAL_FUNC(_sc_system_mass_kill_gtk), &setup);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(button), "clicked",
-                       (GCallback)_sc_system_mass_kill_gtk, &setup);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(button), "clicked",
+                    (GCallback)_sc_system_mass_kill_gtk, &setup);
    sc_dialog_grid_attach(dialog, button, row++, 1);
 
    sc_help_text(help, sizeof(help), "Erase Smoke");
    button = tooltip(w, help, gtk_button_new_with_label(" Erase Smoke "));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                         GTK_SIGNAL_FUNC(_sc_system_erase_smoke_gtk), &setup);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(button), "clicked",
-                       (GCallback)_sc_system_erase_smoke_gtk, &setup);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(button), "clicked",
+                    (GCallback)_sc_system_erase_smoke_gtk, &setup);
    sc_dialog_grid_attach(dialog, button, row++, 1);
 
    sc_help_text(help, sizeof(help), "Retreat");
    button = tooltip(w, help, gtk_button_new_with_label(" N/A:  Retreat "));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                         GTK_SIGNAL_FUNC(_sc_system_retreat_gtk), &setup);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(button), "clicked",
-                       (GCallback)_sc_system_retreat_gtk, &setup);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(button), "clicked",
+                    (GCallback)_sc_system_retreat_gtk, &setup);
    sc_dialog_grid_attach(dialog, button, row++, 1);
 
    sc_help_text(help, sizeof(help), "Resign Game");
    button = tooltip(w, help, gtk_button_new_with_label(" Resign Game "));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                         GTK_SIGNAL_FUNC(_sc_system_resign_gtk), &setup);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(button), "clicked",
-                       (GCallback)_sc_system_resign_gtk, &setup);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(button), "clicked",
+                    (GCallback)_sc_system_resign_gtk, &setup);
    sc_dialog_grid_attach(dialog, button, row++, 1);
 
    sc_help_text(help, sizeof(help), "Sound Setup");
    button = tooltip(w, help, gtk_button_new_with_label(" Sound Setup "));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                         GTK_SIGNAL_FUNC(_sc_system_sound_gtk), &setup);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(button), "clicked",
-                       (GCallback)_sc_system_sound_gtk, &setup);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(button), "clicked",
+                    (GCallback)_sc_system_sound_gtk, &setup);
    sc_dialog_grid_attach(dialog, button, row++, 1);
 
    sc_dialog_run(dialog);
