@@ -1,7 +1,7 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/stank-gtk.c,v 1.20 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/stank-gtk.c,v 1.23 2009-04-26 17:39:50 jacob Exp $ */
 /*
    
-   xscorch - stank-gtk.c      Copyright(c) 2000-2003 Justin David Smith
+   xscorch - stank-gtk.c      Copyright(c) 2000-2004 Justin David Smith
    justins(at)chaos2.org      http://chaos2.org/
     
    Tank configuration screen
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <math.h>
@@ -46,8 +46,8 @@
 
 
 
-static gboolean _sc_window_tank_close_gtk(unused GtkWidget *widget,
-                                          unused ScActiveConsoleSpot *spot,
+static gboolean _sc_window_tank_close_gtk(__libj_unused GtkWidget *widget,
+                                          __libj_unused ScActiveConsoleSpot *spot,
                                           sc_window_gtk *w) {
 
    sc_display_console_detach_all(SC_DISPLAY(w->screen));
@@ -58,8 +58,8 @@ static gboolean _sc_window_tank_close_gtk(unused GtkWidget *widget,
 
 
 
-static gboolean _sc_window_tank_info_key_gtk(unused GtkWidget *widget,
-                                             unused ScActiveConsoleSpot *spot,
+static gboolean _sc_window_tank_info_key_gtk(__libj_unused GtkWidget *widget,
+                                             __libj_unused ScActiveConsoleSpot *spot,
                                              GdkEventKey *key, sc_window_gtk *w) {
 
    switch(key->keyval) {
@@ -86,17 +86,10 @@ void sc_window_tank_info_gtk(sc_window_gtk *w, sc_player *p) {
 
    sc_console_write_line(SC_CONSOLE(console), 36, 6, "< Close >");
    sc_active_console_add_spot(SC_ACTIVE_CONSOLE(console), 36, 6, 9, 1, NULL);
-   #if GTK12_ENABLED
-      gtk_signal_connect_after(GTK_OBJECT(console), "key_press_spot",
-                               GTK_SIGNAL_FUNC(_sc_window_tank_info_key_gtk), w);
-      gtk_signal_connect_after(GTK_OBJECT(console), "select-spot",
-                               GTK_SIGNAL_FUNC(_sc_window_tank_close_gtk), w);
-   #else /* GTK 2.0 */
-      g_signal_connect_after(G_OBJECT(console), "key_press_spot",
-                             (GCallback)_sc_window_tank_info_key_gtk, w);
-      g_signal_connect_after(G_OBJECT(console), "select-spot",
-                             (GCallback)_sc_window_tank_close_gtk, w);
-   #endif /* GTK version? */
+   g_signal_connect_after(G_OBJECT(console), "key_press_spot",
+                          (GCallback)_sc_window_tank_info_key_gtk, w);
+   g_signal_connect_after(G_OBJECT(console), "select-spot",
+                          (GCallback)_sc_window_tank_close_gtk, w);
    
    sbprintf(buf, sizeof(buf), "%2d: %s (%s)", 
             p->index + 1, p->name, sc_ai_name(p->aitype));
@@ -138,7 +131,7 @@ static gboolean _sc_window_tank_move_btn_gtk(GtkWidget *widget, ScActiveConsoleS
    char buf[SC_GTK_STRING_BUFFER];
    int fuel;
 
-   switch((int)spot->data) {
+   switch((long)spot->data) {
       case 1:
          if(sc_player_move(w->c, w->c->plorder[w->c->game->curplayer], -1)) {
             fuel = sc_player_total_fuel(w->c->accessories, w->c->plorder[w->c->game->curplayer]);
@@ -165,7 +158,7 @@ static gboolean _sc_window_tank_move_btn_gtk(GtkWidget *widget, ScActiveConsoleS
 
 
 static gboolean _sc_window_tank_move_key_gtk(GtkWidget *widget, 
-                                             unused ScActiveConsoleSpot *spot,
+                                             __libj_unused ScActiveConsoleSpot *spot,
                                              GdkEventKey *key, sc_window_gtk *w) {
 
    char buf[SC_GTK_STRING_BUFFER];
@@ -225,17 +218,10 @@ void sc_window_tank_move_gtk(sc_window_gtk *w, sc_player *p) {
    sc_console_write_line(SC_CONSOLE(console), 0, 3, "(arrows/buttons move tank,");
    sc_console_write_line(SC_CONSOLE(console), 0, 4, "  [Enter] closes window)");
 
-   #if GTK12_ENABLED
-      gtk_signal_connect_after(GTK_OBJECT(console), "key_press_spot",
-                               GTK_SIGNAL_FUNC(_sc_window_tank_move_key_gtk), w);
-      gtk_signal_connect_after(GTK_OBJECT(console), "select-spot",
-                               GTK_SIGNAL_FUNC(_sc_window_tank_move_btn_gtk), w);
-   #else /* GTK 2.0 */
-      g_signal_connect_after(G_OBJECT(console), "key_press_spot",
-                             (GCallback)_sc_window_tank_move_key_gtk, w);
-      g_signal_connect_after(G_OBJECT(console), "select-spot",
-                             (GCallback)_sc_window_tank_move_btn_gtk, w);
-   #endif /* GTK version? */
+   g_signal_connect_after(G_OBJECT(console), "key_press_spot",
+                          (GCallback)_sc_window_tank_move_key_gtk, w);
+   g_signal_connect_after(G_OBJECT(console), "select-spot",
+                          (GCallback)_sc_window_tank_move_btn_gtk, w);
 
    sc_console_write_line(SC_CONSOLE(console), 2, 6, "< Left >");
    sc_active_console_add_spot(SC_ACTIVE_CONSOLE(console), 2, 6, 8, 1, (void *)1);
