@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/sweapons-gtk.c,v 1.14 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/sweapons-gtk.c,v 1.16 2009-04-26 17:39:51 jacob Exp $ */
 /*
    
    xscorch - sweapons-gtk.c   Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sgtk.h>
@@ -49,7 +49,7 @@ typedef struct _sc_weapons_setup_data_gtk {
 
 
 
-static void _sc_weapons_setup_apply_gtk(unused ScDialog *dlg, sc_weapons_setup_data_gtk *setup) {
+static void _sc_weapons_setup_apply_gtk(__libj_unused ScDialog *dlg, sc_weapons_setup_data_gtk *setup) {
 
    sc_weapon_config *wpc = setup->wpc;
 
@@ -86,13 +86,8 @@ void sc_weapons_setup_gtk(sc_window_gtk *w) {
    setup.uselessitems= wpc->uselessitems;
 
    dialog = SC_DIALOG(sc_dialog_new("Weapon Setup", NULL, confirm | SC_DIALOG_CANCEL));
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(dialog), "apply",
-                         GTK_SIGNAL_FUNC(_sc_weapons_setup_apply_gtk), &setup);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(dialog), "apply",
-                       (GCallback)_sc_weapons_setup_apply_gtk, &setup);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(dialog), "apply",
+                    (GCallback)_sc_weapons_setup_apply_gtk, &setup);
 
    attach_option(dialog, w, "Arms Level",    sc_link_spin_new(&setup.armslevel, 0, SC_ARMS_LEVEL_MAX, 1), &row);
    attach_option(dialog, w, "Bomb Icon Size",sc_link_spin_new(&setup.bombicon, 0, SC_WEAPON_BOMB_ICON_MAX, 1), &row);
