@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sactiveconsole.h,v 1.15 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sactiveconsole.h,v 1.18 2009-05-25 04:03:49 jacob Exp $ */
 /*
 
    xscorch - sactiveconsole.h Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __sactiveconsole_h_included
@@ -39,9 +39,9 @@ struct _ScGadget;
 /***  Active Consoles  ***/
 
 
-#define  SC_ACTIVE_CONSOLE(obj)         GTK_CHECK_CAST(obj, sc_active_console_get_type(), ScActiveConsole)
-#define  SC_ACTIVE_CONSOLE_CLASS(klass) GTK_CHECK_CLASS_CAST(klass, sc_active_console_get_type(), ScActiveConsoleClass)
-#define  IS_SC_ACTIVE_CONSOLE(obj)      GTK_CHECK_TYPE(obj, sc_active_console_get_type())
+#define  SC_ACTIVE_CONSOLE(obj)         G_TYPE_CHECK_INSTANCE_CAST(obj, sc_active_console_get_type(), ScActiveConsole)
+#define  SC_ACTIVE_CONSOLE_CLASS(klass) G_TYPE_CHECK_CLASS_CAST(klass, sc_active_console_get_type(), ScActiveConsoleClass)
+#define  IS_SC_ACTIVE_CONSOLE(obj)      G_TYPE_CHECK_INSTANCE_TYPE(obj, sc_active_console_get_type())
 
 
 typedef struct _ScActiveConsoleSpot {
@@ -78,9 +78,9 @@ typedef struct _ScActiveConsoleClass {
 /***  Gadgets  ***/
 
 
-#define  SC_GADGET(obj)                 GTK_CHECK_CAST(obj, sc_gadget_get_type(), ScGadget)
-#define  SC_GADGET_CLASS(klass)         GTK_CHECK_CLASS_CAST(klass, sc_gadget_get_type(), ScGadgetClass)
-#define  IS_SC_GADGET(obj)              GTK_CHECK_TYPE(obj, sc_gadget_get_type())
+#define  SC_GADGET(obj)                 G_TYPE_CHECK_INSTANCE_CAST(obj, sc_gadget_get_type(), ScGadget)
+#define  SC_GADGET_CLASS(klass)         G_TYPE_CHECK_CLASS_CAST(klass, sc_gadget_get_type(), ScGadgetClass)
+#define  IS_SC_GADGET(obj)              G_TYPE_CHECK_INSTANCE_TYPE(obj, sc_gadget_get_type())
 
 typedef struct _ScGadget {
    GtkObject object;
