@@ -1,9 +1,9 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sactoggle.c,v 1.28 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sactoggle.c,v 1.33 2011-08-01 00:01:42 jacob Exp $ */
 /*
 
-   xscorch - sactoggle.c      Copyright(c) 2001-2003 Jacob Luna Lundberg
+   xscorch - sactoggle.c      Copyright(c) 2001-2011 Jacob Luna Lundberg
                               Copyright(c) 2001-2003 Justin David Smith
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
    justins(at)chaos2.org      http://chaos2.org/~justins
 
    Basic toggle button widget for xscorch consoles.
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <assert.h>
@@ -69,12 +69,12 @@ static void _sc_ac_toggle_draw(ScGadget *gadget) {
    sc_gadget_get_extents(gadget, &bounds);
 
    /* Find out if this gadget has the focus right now. */
-   focus = (GTK_WIDGET_HAS_FOCUS(gadget->console) &&
+   focus = (gtk_widget_has_focus((GtkWidget *)gadget->console) &&
             (gadget->console->current->data == gadget->spot))
            ? TRUE : FALSE;
 
    /* Find out if the gadget will be sensitive. */
-   sensitive = GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(gadget->console));
+   sensitive = gtk_widget_is_sensitive(GTK_WIDGET(gadget->console));
 
    /* Setup the GC colors for the toggle (drawing outer). */
    if(!sensitive)
@@ -146,11 +146,7 @@ static void _sc_ac_toggle_draw(ScGadget *gadget) {
    }
 
    /* Release the GC. */
-   #if GTK12_ENABLED
-      gdk_gc_unref(foreground);
-   #else /* GTK 2.0 */
-      g_object_unref(foreground);
-   #endif /* GTK version? */
+   g_object_unref(foreground);
 
    /* Make sure everything is queued to be drawn. */
    sc_drawbuf_queue_draw(SC_DRAWBUF(widget), bounds.x, bounds.y, bounds.width, bounds.height);
@@ -230,7 +226,7 @@ static void _sc_ac_toggle_class_init(ScACToggleClass *klass) {
 /* _sc_ac_toggle_class_init
    Initialize the toggle class for GTK. */
 
-   parent_class = gtk_type_class(sc_gadget_get_type());
+   parent_class = g_type_class_peek(sc_gadget_get_type());
 
    /* Setup new signal default handlers */
    SC_GADGET_CLASS(klass)->paint             = _sc_ac_toggle_draw;
@@ -258,36 +254,22 @@ GType sc_ac_toggle_get_type(void) {
    static GType sc_ac_toggle_type = 0;
 
    if(sc_ac_toggle_type == 0) {
-      #if GTK12_ENABLED
-         static const GtkTypeInfo sc_ac_toggle_info = {
-            (char *)"ScACToggle",
-            sizeof(ScACToggle),
-            sizeof(ScACToggleClass),
-            (GtkClassInitFunc)_sc_ac_toggle_class_init,
-            (GtkObjectInitFunc)_sc_ac_toggle_init_obj,
-            NULL,
-            NULL,
-            (GtkClassInitFunc)NULL
-         };
-         sc_ac_toggle_type = gtk_type_unique(sc_gadget_get_type(), &sc_ac_toggle_info);
-      #else /* GTK 2.0 */
-         static const GTypeInfo sc_ac_toggle_info = {
-            sizeof(ScACToggleClass),         /* Size of the class object */
-            NULL,                            /* Base initializer */
-            NULL,                            /* Base finalizer */
-            (GClassInitFunc)_sc_ac_toggle_class_init,
-                                             /* Class initializer */
-            NULL,                            /* Class finalizer */
-            NULL,                            /* Class data pointer */
-            sizeof(ScACToggle),              /* Size of an instance object */
-            0,                               /* Number of preallocs */
-            (GInstanceInitFunc)_sc_ac_toggle_init_obj,
-                                             /* Instance initializer */
-            NULL                             /* Value table */
-         };
-         sc_ac_toggle_type = g_type_register_static(sc_gadget_get_type(), "ScACToggle",
-                                                    &sc_ac_toggle_info, 0);
-      #endif /* GTK version? */
+      static const GTypeInfo sc_ac_toggle_info = {
+         sizeof(ScACToggleClass),         /* Size of the class object */
+         NULL,                            /* Base initializer */
+         NULL,                            /* Base finalizer */
+         (GClassInitFunc)_sc_ac_toggle_class_init,
+                                          /* Class initializer */
+         NULL,                            /* Class finalizer */
+         NULL,                            /* Class data pointer */
+         sizeof(ScACToggle),              /* Size of an instance object */
+         0,                               /* Number of preallocs */
+         (GInstanceInitFunc)_sc_ac_toggle_init_obj,
+                                          /* Instance initializer */
+         NULL                             /* Value table */
+      };
+      sc_ac_toggle_type = g_type_register_static(sc_gadget_get_type(), "ScACToggle",
+                                                 &sc_ac_toggle_info, 0);
    }
 
    return(sc_ac_toggle_type);
