@@ -1,9 +1,9 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sactoggle.h,v 1.6 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sactoggle.h,v 1.9 2011-08-01 00:01:42 jacob Exp $ */
 /*
 
    xscorch - sactoggle.h      Copyright(c) 2001-2003 Jacob Luna Lundberg
                               Copyright(c) 2001-2003 Justin David Smith
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
    justins(at)chaos2.org      http://chaos2.org/~justins
 
    Header for scorched toggle button widgets.
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __sactoggle_h_included
@@ -33,9 +33,9 @@
 #include <gtk/gtk.h>
 
 
-#define  SC_AC_TOGGLE(obj)         GTK_CHECK_CAST(obj, sc_ac_toggle_get_type(), ScACToggle)
-#define  SC_AC_TOGGLE_CLASS(klass) GTK_CHECK_CLASS_CAST(klass, sc_ac_toggle_get_type(), ScACToggleClass)
-#define  IS_SC_AC_TOGGLE(obj)      GTK_CHECK_TYPE(obj, sc_ac_toggle_get_type())
+#define  SC_AC_TOGGLE(obj)         G_TYPE_CHECK_INSTANCE_CAST(obj, sc_ac_toggle_get_type(), ScACToggle)
+#define  SC_AC_TOGGLE_CLASS(klass) G_TYPE_CHECK_CLASS_CAST(klass, sc_ac_toggle_get_type(), ScACToggleClass)
+#define  IS_SC_AC_TOGGLE(obj)      G_TYPE_CHECK_INSTANCE_TYPE(obj, sc_ac_toggle_get_type())
 
 
 typedef struct _ScACToggle {
