@@ -15,9 +15,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #define  __ALLOW_DEPRECATED_GDK__
@@ -132,8 +132,8 @@ static inline void _sc_console_init_fonts(ScConsole *cons) {
    Load a reasonable set of default fonts.  */
 
    assert(IS_SC_CONSOLE(cons));
-   cons->screen_font = gdk_font_load("fixed");
-   cons->screen_bold_font = gdk_font_load("fixed");
+   cons->screen_font = gdk_fontset_load("fixed");
+   cons->screen_bold_font = gdk_fontset_load("fixed");
    _sc_console_valid_fonts(cons);
 
 }
@@ -569,7 +569,7 @@ static void _sc_console_draw_region(ScConsole *cons, gint x, gint y, gint width,
          if(_sc_console_in_bounds(cx, cy, cons->cursor.x, cons->cursor.y,
                                   cons->cursor.width, cons->cursor.height)) {
             /* Welp, we're on the cursor.. all that work, for nothing */
-            if(GTK_WIDGET_HAS_FOCUS((GtkWidget *)cons)) {
+            if(gtk_widget_has_focus((GtkWidget *)cons)) {
                if(cons->cursor.highlighted) {
                   fgcolor = &cons->colors.forelight;
                   bgcolor = &cons->colors.backlight;
@@ -613,19 +613,14 @@ static void _sc_console_draw_region(ScConsole *cons, gint x, gint y, gint width,
    g_signal_emit_by_name(GTK_OBJECT(cons), "paint_region", &region, NULL);
 
    /* Release the GC's */
-   #if GTK12_ENABLED
-      gdk_gc_unref(fg_gc);
-      gdk_gc_unref(bg_gc);
-   #else /* GTK 2.0 */
-      g_object_unref(fg_gc);
-      g_object_unref(bg_gc);
-   #endif /* GTK version? */
+   g_object_unref(fg_gc);
+   g_object_unref(bg_gc);
 
 }
 
 
 
-static void _sc_console_draw_horiz_scroll(unused ScConsole *cons) {
+static void _sc_console_draw_horiz_scroll(__libj_unused ScConsole *cons) {
 /* sc_console_draw_horiz_scroll
    Currently not supported :(  */
 
@@ -767,11 +762,7 @@ static void _sc_console_draw_vert_scroll(ScConsole *cons) {
    } /* Down arrow? */
 
    /* Release the GC's */
-   #if GTK12_ENABLED
-      gdk_gc_unref(foreground);
-   #else /* GTK 2.0 */
-      g_object_unref(foreground);
-   #endif /* GTK version? */
+   g_object_unref(foreground);
 
    /* Make sure everything is queued for draw */
    sc_drawbuf_queue_draw(SC_DRAWBUF(widget), startx, starty - arrowh,
@@ -828,13 +819,8 @@ static void _sc_console_draw_frame(ScConsole *cons) {
    } /* Draw the window border? */
 
    /* Release the GC's */
-   #if GTK12_ENABLED
-      gdk_gc_unref(foreground);
-      gdk_gc_unref(background);
-   #else /* GTK 2.0 */
-      g_object_unref(foreground);
-      g_object_unref(background);
-   #endif /* GTK version? */
+   g_object_unref(foreground);
+   g_object_unref(background);
 
 }
 
@@ -919,7 +905,7 @@ static gint _sc_console_draw_focus(GtkWidget *widget, GdkEventFocus *event) {
 
    ScConsole *cons = SC_CONSOLE(widget);
 
-   GTK_WIDGET_SET_FLAGS(widget, GTK_HAS_FOCUS);
+   gtk_widget_grab_focus(widget);
    _sc_console_draw_region(cons, cons->cursor.x, cons->cursor.y, cons->cursor.width, cons->cursor.height);
 
    /* Check for a parent signal handler */
@@ -936,12 +922,10 @@ static gint _sc_console_draw_focus(GtkWidget *widget, GdkEventFocus *event) {
 
 static gint _sc_console_undraw_focus(GtkWidget *widget, GdkEventFocus *event) {
 /* sc_console_undraw_focus
-   Draws the console's cursor as if it were unfocused.  This sets the GTK
-   flags to indicate the console no longer has the focus.  */
+   Draws the console's cursor as if it were unfocused.  */
 
    ScConsole *cons = SC_CONSOLE(widget);
 
-   GTK_WIDGET_UNSET_FLAGS(widget, GTK_HAS_FOCUS);
    _sc_console_draw_region(cons, cons->cursor.x, cons->cursor.y, cons->cursor.width, cons->cursor.height);
 
    /* Check for a parent signal handler */
@@ -1150,37 +1134,23 @@ static void _sc_console_class_init(ScConsoleClass *klass) {
    GtkObjectClass *object_class = (GtkObjectClass *)klass;
 
    /* Determine parent class */
-   parent_class = gtk_type_class(sc_drawbuf_get_type());
+   parent_class = g_type_class_peek(sc_drawbuf_get_type());
 
    /* Construct new signals */
-   #if GTK12_ENABLED
-      _sc_console_signals[PAINT_REGION_SIGNAL] =
-         gtk_signal_new("paint_region",
-                        GTK_RUN_LAST,
-                        GTK_CLASS_TYPE(object_class),
-                        GTK_SIGNAL_OFFSET(ScConsoleClass, paint_region),
-                        gtk_marshal_NONE__POINTER,
-                        GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
-
-      /* Install the new signals */
-      /* This call is no longer necessary in 2.0 */
-      gtk_object_class_add_signals(object_class, _sc_console_signals, LAST_SIGNAL);
-   #else /* GTK 2.0 */
-      _sc_console_signals[PAINT_REGION_SIGNAL] =
-         g_signal_new("paint_region",                 /* Signal name */
-                      G_TYPE_FROM_CLASS(object_class),/* Type of object the signal applies to */
-                      G_SIGNAL_RUN_LAST,              /* Signal flags; run this signal last */
-                      offsetof(ScConsoleClass, paint_region),
-                                                      /* Offset to signal handler in class */
-                      NULL,                           /* Signal accumulator function */
-                      NULL,                           /* Signal accumulator data */
-                      g_cclosure_marshal_VOID__POINTER,
-                                                      /* Marshal function for this signal */
-                      G_TYPE_NONE,                    /* Return type for the marshaller */
-                      1,                              /* Number of extra parametres to pass */
-                      G_TYPE_POINTER                  /* Type of first parametre to marshaller */
-                     );
-   #endif /* GTK version? */
+   _sc_console_signals[PAINT_REGION_SIGNAL] =
+      g_signal_new("paint_region",                 /* Signal name */
+                   G_TYPE_FROM_CLASS(object_class),/* Type of object the signal applies to */
+                   G_SIGNAL_RUN_LAST,              /* Signal flags; run this signal last */
+                   offsetof(ScConsoleClass, paint_region),
+                                                   /* Offset to signal handler in class */
+                   NULL,                           /* Signal accumulator function */
+                   NULL,                           /* Signal accumulator data */
+                   g_cclosure_marshal_VOID__POINTER,
+                                                   /* Marshal function for this signal */
+                   G_TYPE_NONE,                    /* Return type for the marshaller */
+                   1,                              /* Number of extra parametres to pass */
+                   G_TYPE_POINTER                  /* Type of first parametre to marshaller */
+                  );
 
    /* Attach default signal handlers */
    klass->paint_region                          = NULL;
@@ -1235,7 +1205,7 @@ static void _sc_console_init_obj(ScConsole *cons) {
    cons->colors.bold = FALSE;
 
    /* Make sure the console is focusable. */
-   GTK_WIDGET_SET_FLAGS(cons, GTK_CAN_FOCUS);
+   gtk_widget_set_can_focus(GTK_WIDGET(cons), TRUE);
 
 }
 
@@ -1248,36 +1218,22 @@ GType sc_console_get_type(void) {
    static GType sc_console_type = 0;
 
    if(sc_console_type == 0) {
-      #if GTK12_ENABLED
-         static const GtkTypeInfo sc_console_info = {
-            (char *)"ScConsole",
-            sizeof(ScConsole),
-            sizeof(ScConsoleClass),
-            (GtkClassInitFunc)_sc_console_class_init,
-            (GtkObjectInitFunc)_sc_console_init_obj,
-            NULL,
-            NULL,
-            (GtkClassInitFunc)NULL
-         };
-         sc_console_type = gtk_type_unique(sc_drawbuf_get_type(), &sc_console_info);
-      #else /* GTK 2.0 */
-         static const GTypeInfo sc_console_info = {
-            sizeof(ScConsoleClass),          /* Size of the class object */
-            NULL,                            /* Base initializer */
-            NULL,                            /* Base finalizer */
-            (GClassInitFunc)_sc_console_class_init,
-                                             /* Class initializer */
-            NULL,                            /* Class finalizer */
-            NULL,                            /* Class data pointer */
-            sizeof(ScConsole),               /* Size of an instance object */
-            0,                               /* Number of preallocs */
-            (GInstanceInitFunc)_sc_console_init_obj,
-                                             /* Instance initializer */
-            NULL                             /* Value table */
-         };
-         sc_console_type = g_type_register_static(sc_drawbuf_get_type(), "ScConsole",
-                                                  &sc_console_info, 0);
-      #endif /* GTK version? */
+      static const GTypeInfo sc_console_info = {
+         sizeof(ScConsoleClass),          /* Size of the class object */
+         NULL,                            /* Base initializer */
+         NULL,                            /* Base finalizer */
+         (GClassInitFunc)_sc_console_class_init,
+                                          /* Class initializer */
+         NULL,                            /* Class finalizer */
+         NULL,                            /* Class data pointer */
+         sizeof(ScConsole),               /* Size of an instance object */
+         0,                               /* Number of preallocs */
+         (GInstanceInitFunc)_sc_console_init_obj,
+                                          /* Instance initializer */
+         NULL                             /* Value table */
+      };
+      sc_console_type = g_type_register_static(sc_drawbuf_get_type(), "ScConsole",
+                                               &sc_console_info, 0);
    }
 
    return(sc_console_type);
