@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sconsole.h,v 1.16 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sconsole.h,v 1.18 2009-04-26 17:39:53 jacob Exp $ */
 /*
 
    xscorch - sconsole.h       Copyright(c) 2000-2003 Justin David Smith
@@ -16,24 +16,24 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __sconsole_h_included
 #define __sconsole_h_included
 
 
-#include <sgtk.h>
 #include <gtk/gtk.h>
+#include <sgtk.h>
 #include <sdrawbuf.h>
 
 
 /* Console typecasts */
-#define  SC_CONSOLE(obj)         GTK_CHECK_CAST(obj, sc_console_get_type(), ScConsole)
-#define  SC_CONSOLE_CLASS(klass) GTK_CHECK_CLASS_CAST(klass, sc_console_get_type(), ScConsoleClass)
-#define  IS_SC_CONSOLE(obj)      GTK_CHECK_TYPE(obj, sc_console_get_type())
+#define  SC_CONSOLE(obj)         G_TYPE_CHECK_INSTANCE_CAST(obj, sc_console_get_type(), ScConsole)
+#define  SC_CONSOLE_CLASS(klass) G_TYPE_CHECK_CLASS_CAST(klass, sc_console_get_type(), ScConsoleClass)
+#define  IS_SC_CONSOLE(obj)      G_TYPE_CHECK_INSTANCE_TYPE(obj, sc_console_get_type())
 
 
 /* Console style information */
