@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sdialog.c,v 1.30 2004/03/25 03:47:01 jacob Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sdialog.c,v 1.32 2009-04-26 17:39:53 jacob Exp $ */
 /*
 
    xscorch - sdialog.c        Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #define  __ALLOW_DEPRECATED_GDK__
@@ -57,7 +57,7 @@ static void _sc_dialog_destroy(GtkObject *obj) {
 /* sc_dialog_destroy
    Destroy a dialogue window.  If the state pointer is not NULL, then the
    state is updated to indicate the dialog has been destroyed.  The parent
-  destructor will be called.  */
+   destructor will be called.  */
 
    ScDialog *dlg = SC_DIALOG(obj);
 
@@ -75,7 +75,7 @@ static void _sc_dialog_destroy(GtkObject *obj) {
 
 
 
-static void _sc_dialog_apply_clicked(unused GtkWidget *button, ScDialog *dlg) {
+static void _sc_dialog_apply_clicked(__libj_unused GtkWidget *button, ScDialog *dlg) {
 /* sc_dialog_apply_clicked
    The Apply button was clicked.  Emit the "apply" signal, causing
    any changes in the dialog window to take effect.  This button
@@ -86,13 +86,9 @@ static void _sc_dialog_apply_clicked(unused GtkWidget *button, ScDialog *dlg) {
    /* Emit "apply" signal, causing changes to take effect. Reference
       this dialog window while we process the signal, to ensure that
       it does not get prematurely destroyed.  */
-   gtk_widget_ref(GTK_WIDGET(dlg));
-   #if GTK12_ENABLED
-      gtk_signal_emit(GTK_OBJECT(dlg), _sc_dialog_signals[APPLY_SIGNAL]);
-   #else /* GTK 2.0 */
-      g_signal_emit(GTK_OBJECT(dlg), _sc_dialog_signals[APPLY_SIGNAL], 0);
-   #endif /* GTK version? */
-   gtk_widget_unref(GTK_WIDGET(dlg));
+   g_object_ref(G_OBJECT(dlg));
+   g_signal_emit(GTK_OBJECT(dlg), _sc_dialog_signals[APPLY_SIGNAL], 0);
+   g_object_unref(G_OBJECT(dlg));
 
 }
 
@@ -122,7 +118,7 @@ static void _sc_dialog_ok_clicked(GtkWidget *button, ScDialog *dlg) {
 
 
 
-static void _sc_dialog_cancel_clicked(unused GtkWidget *button, ScDialog *dlg) {
+static void _sc_dialog_cancel_clicked(__libj_unused GtkWidget *button, ScDialog *dlg) {
 /* sc_dialog_cancel_clicked
    The Cancel button was clicked.  Close the dialogue window without
    emitting an "apply" signal; changes in the dialog are discarded.
@@ -198,33 +194,20 @@ static void _sc_dialog_class_init(ScDialogClass *klass) {
    GtkObjectClass *object_class = (GtkObjectClass *)klass;
 
    /* Get parent class */
-   parent_class = gtk_type_class(gtk_window_get_type());
+   parent_class = g_type_class_peek(gtk_window_get_type());
 
-   #if GTK12_ENABLED
-      _sc_dialog_signals[APPLY_SIGNAL] =
-         gtk_signal_new("apply",
-                        GTK_RUN_LAST,
-                        GTK_CLASS_TYPE(object_class),
-                        GTK_SIGNAL_OFFSET(ScDialogClass, apply),
-                        gtk_marshal_NONE__NONE,
-                        GTK_TYPE_NONE, 0);
-
-      /* This call is no longer necessary in 2.0 */
-      gtk_object_class_add_signals(object_class, _sc_dialog_signals, LAST_SIGNAL);
-   #else /* GTK 2.0 */
-      _sc_dialog_signals[APPLY_SIGNAL] =
-         g_signal_new("apply",                        /* Signal name */
-                      G_TYPE_FROM_CLASS(object_class),/* Type of object the signal applies to */
-                      G_SIGNAL_RUN_LAST,              /* Signal flags; run this signal last */
-                      offsetof(ScDialogClass, apply),
-                                                      /* Offset to signal handler in class */
-                      NULL,                           /* Signal accumulator function */
-                      NULL,                           /* Signal accumulator data */
-                      g_cclosure_marshal_VOID__VOID,  /* Marshal function for this signal */
-                      G_TYPE_NONE,                    /* Return type for the marshaller */
-                      0                               /* Number of extra parametres to pass */
-                     );
-   #endif /* GTK version? */
+   _sc_dialog_signals[APPLY_SIGNAL] =
+      g_signal_new("apply",                        /* Signal name */
+                   G_TYPE_FROM_CLASS(object_class),/* Type of object the signal applies to */
+                   G_SIGNAL_RUN_LAST,              /* Signal flags; run this signal last */
+                   offsetof(ScDialogClass, apply),
+                                                   /* Offset to signal handler in class */
+                   NULL,                           /* Signal accumulator function */
+                   NULL,                           /* Signal accumulator data */
+                   g_cclosure_marshal_VOID__VOID,  /* Marshal function for this signal */
+                   G_TYPE_NONE,                    /* Return type for the marshaller */
+                   0                               /* Number of extra parametres to pass */
+                  );
 
    /* Setup new signals */
    klass->apply = NULL;
@@ -254,36 +237,22 @@ GType sc_dialog_get_type(void) {
    static GType sc_dialog_type = 0;
 
    if(sc_dialog_type == 0) {
-      #if GTK12_ENABLED
-         static const GtkTypeInfo sc_dialog_info = {
-            (char *)"ScDialog",
-            sizeof(ScDialog),
-            sizeof(ScDialogClass),
-            (GtkClassInitFunc)_sc_dialog_class_init,
-            (GtkObjectInitFunc)_sc_dialog_init_obj,
-            NULL,
-            NULL,
-            (GtkClassInitFunc)NULL
-         };
-         sc_dialog_type = gtk_type_unique(gtk_window_get_type(), &sc_dialog_info);
-      #else /* GTK 2.0 */
-         static const GTypeInfo sc_dialog_info = {
-            sizeof(ScDialogClass),           /* Size of the class object */
-            NULL,                            /* Base initializer */
-            NULL,                            /* Base finalizer */
-            (GClassInitFunc)_sc_dialog_class_init,
-                                             /* Class initializer */
-            NULL,                            /* Class finalizer */
-            NULL,                            /* Class data pointer */
-            sizeof(ScDialog),                /* Size of an instance object */
-            0,                               /* Number of preallocs */
-            (GInstanceInitFunc)_sc_dialog_init_obj,
-                                             /* Instance initializer */
-            NULL                             /* Value table */
-         };
-         sc_dialog_type = g_type_register_static(gtk_window_get_type(), "ScDialog",
-                                                 &sc_dialog_info, 0);
-      #endif /* GTK version? */
+      static const GTypeInfo sc_dialog_info = {
+         sizeof(ScDialogClass),           /* Size of the class object */
+         NULL,                            /* Base initializer */
+         NULL,                            /* Base finalizer */
+         (GClassInitFunc)_sc_dialog_class_init,
+                                          /* Class initializer */
+         NULL,                            /* Class finalizer */
+         NULL,                            /* Class data pointer */
+         sizeof(ScDialog),                /* Size of an instance object */
+         0,                               /* Number of preallocs */
+         (GInstanceInitFunc)_sc_dialog_init_obj,
+                                          /* Instance initializer */
+         NULL                             /* Value table */
+      };
+      sc_dialog_type = g_type_register_static(gtk_window_get_type(), "ScDialog",
+                                              &sc_dialog_info, 0);
    }
 
    return(sc_dialog_type);
@@ -337,69 +306,36 @@ GtkWidget *sc_dialog_new(const char *title, const char *msgtext, guint flags) {
    /* This box houses the command buttons and should not rescale vertically */
    gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
-   #if GTK12_ENABLED
-      if(flags & SC_DIALOG_CLOSE) {
-         btn = gtk_button_new_with_label(" Close ");
-         gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(_sc_dialog_cancel_clicked), dialog);
-         gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
-      }
-      if(flags & SC_DIALOG_APPLY) {
-         btn = gtk_button_new_with_label(" Apply ");
-         gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(_sc_dialog_apply_clicked), dialog);
-         gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
-      }
-      if(flags & SC_DIALOG_NO) {
-         btn = gtk_button_new_with_label(" No ");
-         gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(_sc_dialog_cancel_clicked), dialog);
-         gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
-      }
-      if(flags & SC_DIALOG_CANCEL) {
-         btn = gtk_button_new_with_label(" Cancel ");
-         gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(_sc_dialog_cancel_clicked), dialog);
-         gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
-      }
-      if(flags & SC_DIALOG_YES) {
-         btn = gtk_button_new_with_label(" Yes ");
-         gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(_sc_dialog_ok_clicked), dialog);
-         gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
-      }
-      if(flags & SC_DIALOG_OK) {
-         btn = gtk_button_new_with_label(" Ok ");
-         gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(_sc_dialog_ok_clicked), dialog);
-         gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
-      }
-   #else /* GTK 2.0 */
-      if(flags & SC_DIALOG_CLOSE) {
-         btn = gtk_button_new_with_label(" Close ");
-         g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)_sc_dialog_cancel_clicked, dialog);
-         gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
-      }
-      if(flags & SC_DIALOG_APPLY) {
-         btn = gtk_button_new_with_label(" Apply ");
-         g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)_sc_dialog_apply_clicked, dialog);
-         gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
-      }
-      if(flags & SC_DIALOG_NO) {
-         btn = gtk_button_new_with_label(" No ");
-         g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)_sc_dialog_cancel_clicked, dialog);
-         gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
-      }
-      if(flags & SC_DIALOG_CANCEL) {
-         btn = gtk_button_new_with_label(" Cancel ");
-         g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)_sc_dialog_cancel_clicked, dialog);
-         gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
-      }
-      if(flags & SC_DIALOG_YES) {
-         btn = gtk_button_new_with_label(" Yes ");
-         g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)_sc_dialog_ok_clicked, dialog);
-         gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
-      }
-      if(flags & SC_DIALOG_OK) {
-         btn = gtk_button_new_with_label(" Ok ");
-         g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)_sc_dialog_ok_clicked, dialog);
-         gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
-      }
-   #endif /* GTK version? */
+   if(flags & SC_DIALOG_CLOSE) {
+      btn = gtk_button_new_with_label(" Close ");
+      g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)_sc_dialog_cancel_clicked, dialog);
+      gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
+   }
+   if(flags & SC_DIALOG_APPLY) {
+      btn = gtk_button_new_with_label(" Apply ");
+      g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)_sc_dialog_apply_clicked, dialog);
+      gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
+   }
+   if(flags & SC_DIALOG_NO) {
+      btn = gtk_button_new_with_label(" No ");
+      g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)_sc_dialog_cancel_clicked, dialog);
+      gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
+   }
+   if(flags & SC_DIALOG_CANCEL) {
+      btn = gtk_button_new_with_label(" Cancel ");
+      g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)_sc_dialog_cancel_clicked, dialog);
+      gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
+   }
+   if(flags & SC_DIALOG_YES) {
+      btn = gtk_button_new_with_label(" Yes ");
+      g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)_sc_dialog_ok_clicked, dialog);
+      gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
+   }
+   if(flags & SC_DIALOG_OK) {
+      btn = gtk_button_new_with_label(" Ok ");
+      g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)_sc_dialog_ok_clicked, dialog);
+      gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 5);
+   }
 
    dialog->flags = flags;
    return(GTK_WIDGET(dialog));
@@ -546,200 +482,6 @@ void sc_dialog_error(const char *s) {
 
 
 
-#if GTK12_ENABLED
-
-/* GTK 2.0 uses GtkTextView, not GtkText */
-#define  GTK_TEXT_VIEW                 GTK_TEXT
-#define  gtk_text_view_new()           gtk_text_new(NULL, NULL)
-#define  gtk_text_view_set_editable    gtk_text_set_editable
-#define  gtk_text_view_insert          gtk_text_insert
-   
-void sc_dialog_text(const char *filename, GdkFont *font_normal, GdkFont *font_italic, GdkFont *font_bold) {
-
-   ScDialog *dlg;
-   char buf[SC_DIALOG_STRING_BUFFER];
-   char out[SC_DIALOG_STRING_BUFFER];
-   char *pin;
-   char *pout;
-   int  width;
-   int height;
-   FILE *f;
-   GdkFont *font;
-   GdkFont *lfont;
-   GtkWidget *scroll;
-   GtkWidget *message;
-
-   dlg = SC_DIALOG(sc_dialog_new(filename, NULL, SC_DIALOG_CLOSE | SC_DIALOG_NONMODAL));
-
-   if((f = fopen(filename, "r")) == NULL) {
-      sbprintf(buf, sizeof(buf), "Cannot open file %s.\n", filename);
-      sc_dialog_error(buf);
-      return;
-   }
-
-   /* Load the needed fonts */
-   if(font_normal != NULL) gdk_font_ref(font_normal);
-   if(font_italic != NULL) gdk_font_ref(font_italic);
-   if(font_bold   != NULL) gdk_font_ref(font_bold);
-   if(font_normal == NULL) {
-      width = 8;
-      height = 16;
-   } else {
-      width = gdk_char_width(font_normal, 'W');
-      height = (font_normal->ascent + font_normal->descent);
-   }
-   width  *= 88;
-   height *= 33;
-
-   scroll = gtk_scrolled_window_new(NULL, NULL);
-   sc_dialog_grid_attach(dlg, scroll, 0, 0);
-   gtk_widget_set_size_request(scroll, width, height);
-
-   message = gtk_text_view_new();
-   gtk_text_view_set_editable(GTK_TEXT_VIEW(message), FALSE);
-   gtk_container_add(GTK_CONTAINER(scroll), message);
-
-   /* Load in the text data */
-   gtk_text_freeze(GTK_TEXT(message));
-   while(fgets(buf, SC_DIALOG_STRING_BUFFER, f)) {
-      pin   = buf;
-      pout  = out;
-      font  = NULL;
-      lfont = font_normal;
-      while(*pin != '\0') {
-         if(*(pin + 1) != 0x08) {
-            font = font_normal;
-         } else {
-            font = (*pin == '_' ? font_italic : font_bold);
-            pin += 2;
-         }
-         if(font != lfont) {
-            if(pout - out > 0) {
-               gtk_text_view_insert(GTK_TEXT_VIEW(message), lfont, NULL, NULL, out, pout - out);
-            }
-            pout  = out;
-            lfont = font;
-         }
-         *(pout++) = *pin;
-         if(*pin == '\n') {
-            *(pout++) = ' ';
-            *(pout++) = ' ';
-         }
-         pin++;
-      }
-      if(pout - out > 0) {
-         gtk_text_view_insert(GTK_TEXT_VIEW(message), lfont, NULL, NULL, out, pout - out);
-      }
-   }
-   if(font_normal != NULL) {
-      gdk_font_unref(font_normal);
-   }
-   if(font_italic != NULL) {
-      gdk_font_unref(font_italic);
-   }
-   if(font_bold   != NULL) {
-      gdk_font_unref(font_bold);
-   }
-   gtk_text_thaw(GTK_TEXT(message));
-   fclose(f);
-
-   sc_dialog_show(dlg);
-   return;
-
-}
-
-
-
-void sc_dialog_text_buffer(const char *title, const char *buffer,
-                           GdkFont *font_normal, GdkFont *font_italic, GdkFont *font_bold) {
-
-   ScDialog *dlg;
-   char buf[SC_DIALOG_STRING_BUFFER];
-   char out[SC_DIALOG_STRING_BUFFER];
-   char *pin;
-   char *pout;
-   int  width;
-   int height;
-   int offset = 0;
-   GdkFont *font;
-   GdkFont *lfont;
-   GtkWidget *scroll;
-   GtkWidget *message;
-
-   dlg = SC_DIALOG(sc_dialog_new(title, NULL, SC_DIALOG_CLOSE | SC_DIALOG_NONMODAL));
-
-   /* Load the needed fonts */
-   if(font_normal != NULL) gdk_font_ref(font_normal);
-   if(font_italic != NULL) gdk_font_ref(font_italic);
-   if(font_bold   != NULL) gdk_font_ref(font_bold);
-   if(font_normal == NULL) {
-      width = 8;
-      height = 16;
-   } else {
-      width = gdk_char_width(font_normal, 'W');
-      height = (font_normal->ascent + font_normal->descent);
-   }
-   width  *= 88;
-   height *= 33;
-
-   scroll = gtk_scrolled_window_new(NULL, NULL);
-   sc_dialog_grid_attach(dlg, scroll, 0, 0);
-   gtk_widget_set_size_request(scroll, width, height);
-
-   message = gtk_text_view_new();
-   gtk_text_view_set_editable(GTK_TEXT_VIEW(message), FALSE);
-   gtk_container_add(GTK_CONTAINER(scroll), message);
-
-   /* Load in the text data */
-   gtk_text_freeze(GTK_TEXT(message));
-   while(sgetline(buf, SC_DIALOG_STRING_BUFFER, buffer, &offset) != NULL) {
-      pin   = buf;
-      pout  = out;
-      font  = NULL;
-      lfont = font_normal;
-      while(*pin != '\0') {
-         if(*(pin + 1) != 0x08) {
-            font = font_normal;
-         } else {
-            font = (*pin == '_' ? font_italic : font_bold);
-            pin += 2;
-         }
-         if(font != lfont) {
-            if(pout - out > 0) {
-               gtk_text_view_insert(GTK_TEXT_VIEW(message), lfont, NULL, NULL, out, pout - out);
-            }
-            pout  = out;
-            lfont = font;
-         }
-         *(pout++) = *pin;
-         if(*pin == '\n') {
-            *(pout++) = ' ';
-            *(pout++) = ' ';
-         }
-         pin++;
-      }
-      if(pout - out > 0) {
-         gtk_text_view_insert(GTK_TEXT_VIEW(message), lfont, NULL, NULL, out, pout - out);
-      }
-   }
-   if(font_normal != NULL) {
-      gdk_font_unref(font_normal);
-   }
-   if(font_italic != NULL) {
-      gdk_font_unref(font_italic);
-   }
-   if(font_bold   != NULL) {
-      gdk_font_unref(font_bold);
-   }
-   gtk_text_thaw(GTK_TEXT(message));
-
-   sc_dialog_show(dlg);
-   return;
-
-}
-
-#else /* GTK 2.0 */
-
 void sc_dialog_text(const char *filename, GdkFont *font_normal, GdkFont *font_italic, GdkFont *font_bold) {
 
    ScDialog *dlg;
@@ -999,5 +741,3 @@ void sc_dialog_text_buffer(const char *title, const char *buffer,
    return;
 
 }
-
-#endif /* GTK version? */
