@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sdialog.h,v 1.9 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sdialog.h,v 1.11 2009-04-26 17:39:53 jacob Exp $ */
 /*
 
    xscorch - sdialog.h        Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __sdialog_h_included
@@ -35,9 +35,9 @@
 
 
 /* Dialog typecasts */
-#define  SC_DIALOG(obj)          GTK_CHECK_CAST(obj, sc_dialog_get_type(), ScDialog)
-#define  SC_DIALOG_CLASS(klass)  GTK_CHECK_CLASS_CAST(klass, sc_dialog_get_type(), ScDialogClass)
-#define  IS_SC_DIALOG(obj)       GTK_CHECK_TYPE(obj, sc_dialog_get_type())
+#define  SC_DIALOG(obj)          G_TYPE_CHECK_INSTANCE_CAST(obj, sc_dialog_get_type(), ScDialog)
+#define  SC_DIALOG_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST(klass, sc_dialog_get_type(), ScDialogClass)
+#define  IS_SC_DIALOG(obj)       G_TYPE_CHECK_INSTANCE_TYPE(obj, sc_dialog_get_type())
 
 
 /* Dialog attributes */
@@ -94,5 +94,3 @@ void sc_dialog_text_buffer(const char *title, const char *buffer, GdkFont *norma
 
 
 #endif /* __sdialog_h_included */
-
-
