@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sdisplay.c,v 1.15 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sdisplay.c,v 1.18 2011-04-15 06:04:26 jacob Exp $ */
 /*
 
    xscorch - sdisplay.c       Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <assert.h>
@@ -31,8 +31,8 @@ static void _sc_display_init_obj(ScDisplay *dpy) {
 
    assert(IS_SC_DISPLAY(dpy));
    dpy->draw = NULL;
-   GTK_WIDGET_UNSET_FLAGS(GTK_WIDGET(dpy), GTK_CAN_FOCUS);
-   
+   gtk_widget_set_can_focus(GTK_WIDGET(dpy), FALSE);
+
 }
 
 
@@ -42,35 +42,21 @@ GType sc_display_get_type(void) {
    static GType sc_display_type = 0;
 
    if(sc_display_type == 0) {
-      #if GTK12_ENABLED
-         static const GtkTypeInfo sc_display_info = {
-            (char *)"ScDisplay",
-            sizeof(ScDisplay),
-            sizeof(ScDisplayClass),
-            NULL,
-            (GtkObjectInitFunc)_sc_display_init_obj,
-            NULL,
-            NULL,
-            (GtkClassInitFunc)NULL
-         };
-         sc_display_type = gtk_type_unique(gtk_fixed_get_type(), &sc_display_info);
-      #else /* GTK 2.0 */
-         static const GTypeInfo sc_display_info = {
-            sizeof(ScDisplayClass),          /* Size of the class object */
-            NULL,                            /* Base initializer */
-            NULL,                            /* Base finalizer */
-            NULL,                            /* Class initializer */
-            NULL,                            /* Class finalizer */
-            NULL,                            /* Class data pointer */
-            sizeof(ScDisplay),               /* Size of an instance object */
-            0,                               /* Number of preallocs */
-            (GInstanceInitFunc)_sc_display_init_obj,
-                                             /* Instance initializer */
-            NULL                             /* Value table */
-         };
-         sc_display_type = g_type_register_static(gtk_fixed_get_type(), "ScDisplay",
-                                                  &sc_display_info, 0);
-      #endif /* GTK version? */
+      static const GTypeInfo sc_display_info = {
+         sizeof(ScDisplayClass),          /* Size of the class object */
+         NULL,                            /* Base initializer */
+         NULL,                            /* Base finalizer */
+         NULL,                            /* Class initializer */
+         NULL,                            /* Class finalizer */
+         NULL,                            /* Class data pointer */
+         sizeof(ScDisplay),               /* Size of an instance object */
+         0,                               /* Number of preallocs */
+         (GInstanceInitFunc)_sc_display_init_obj,
+                                          /* Instance initializer */
+         NULL                             /* Value table */
+      };
+      sc_display_type = g_type_register_static(gtk_fixed_get_type(), "ScDisplay",
+                                               &sc_display_info, 0);
    }
 
    return(sc_display_type);
