@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sdisplay.h,v 1.6 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sdisplay.h,v 1.8 2009-04-26 17:39:53 jacob Exp $ */
 /*
 
    xscorch - sdisplay.h       Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __sdisplay_h_included
@@ -32,9 +32,9 @@
 #include <sconsole.h>
 
 
-#define  SC_DISPLAY(obj)         GTK_CHECK_CAST(obj, sc_display_get_type(), ScDisplay)
-#define  SC_DISPLAY_CLASS(klass) GTK_CHECK_CLASS_CAST(klass, sc_display_get_type(), ScDisplayClass)
-#define  IS_SC_DISPLAY(obj)      GTK_CHECK_TYPE(obj, sc_display_get_type())
+#define  SC_DISPLAY(obj)         G_TYPE_CHECK_INSTANCE_CAST(obj, sc_display_get_type(), ScDisplay)
+#define  SC_DISPLAY_CLASS(klass) G_TYPE_CHECK_CLASS_CAST(klass, sc_display_get_type(), ScDisplayClass)
+#define  IS_SC_DISPLAY(obj)      G_TYPE_CHECK_INSTANCE_TYPE(obj, sc_display_get_type())
 
 
 typedef struct _ScDisplay {
