@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sdrawbuf.c,v 1.16 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/sdrawbuf.c,v 1.20 2011-07-31 19:48:00 jacob Exp $ */
 /*
 
    xscorch - sdrawbuf.c       Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <sdrawbuf.h>
@@ -32,25 +32,14 @@ static GtkDrawingAreaClass *parent_class;
 static inline void _sc_drawbuf_unref_pixmap_and_gc(ScDrawbuf *draw) {
 
    /* Release associated GC, pixmap */
-   #if GTK12_ENABLED
-      if(sc_drawbuf_get_buffer(draw) != NULL) {
-         gdk_pixmap_unref(sc_drawbuf_get_buffer(draw));
-         sc_drawbuf_get_buffer(draw) = NULL;
-      }
-      if(sc_drawbuf_get_gc(draw) != NULL) {
-         gdk_gc_unref(sc_drawbuf_get_gc(draw));
-         sc_drawbuf_get_gc(draw) = NULL;
-      }
-   #else /* GTK 2.0 */
-      if(sc_drawbuf_get_buffer(draw) != NULL) {
-         g_object_unref(sc_drawbuf_get_buffer(draw));
-         sc_drawbuf_get_buffer(draw) = NULL;
-      }
-      if(sc_drawbuf_get_gc(draw) != NULL) {
-         g_object_unref(sc_drawbuf_get_gc(draw));
-         sc_drawbuf_get_gc(draw) = NULL;
-      }
-   #endif /* GTK version? */
+   if(sc_drawbuf_get_buffer(draw) != NULL) {
+      g_object_unref(sc_drawbuf_get_buffer(draw));
+      sc_drawbuf_get_buffer(draw) = NULL;
+   }
+   if(sc_drawbuf_get_gc(draw) != NULL) {
+      g_object_unref(sc_drawbuf_get_gc(draw));
+      sc_drawbuf_get_gc(draw) = NULL;
+   }
 
 }
 
@@ -127,7 +116,7 @@ static gint _sc_drawbuf_configure(GtkWidget *widget, GdkEventConfigure *event) {
 static gint _sc_drawbuf_expose(GtkWidget *widget, GdkEventExpose *event) {
 
    ScDrawbuf *draw = SC_DRAWBUF(widget);
-   GdkGC *fg_gc = widget->style->fg_gc[GTK_WIDGET_STATE((GtkWidget *)draw)];
+   GdkGC *fg_gc = widget->style->fg_gc[gtk_widget_get_state((GtkWidget *)draw)];
 
    /* Make sure buffer is allocated */
    g_return_val_if_fail(sc_drawbuf_get_buffer(draw) != NULL, TRUE);
@@ -149,7 +138,7 @@ static gint _sc_drawbuf_expose(GtkWidget *widget, GdkEventExpose *event) {
 static void _sc_drawbuf_class_init(ScDrawbufClass *klass) {
 
    /* Determine the parent class */
-   parent_class = gtk_type_class(gtk_drawing_area_get_type());
+   parent_class = g_type_class_peek(gtk_drawing_area_get_type());
 
    /* Latch default hooks */
    GTK_WIDGET_CLASS(klass)->configure_event = _sc_drawbuf_configure;
@@ -167,20 +156,15 @@ static void _sc_drawbuf_init_obj(ScDrawbuf *draw) {
    draw->style_configured = FALSE;
 
    /* Setup widget, and object signals */
-   GTK_WIDGET_UNSET_FLAGS(GTK_WIDGET(draw), GTK_CAN_FOCUS);
+   gtk_widget_set_can_focus(GTK_WIDGET(draw), FALSE);
    gtk_widget_add_events(GTK_WIDGET(draw), GDK_EXPOSURE_MASK);
    gtk_widget_set_app_paintable(GTK_WIDGET(draw), TRUE);
 
    /* Install expose event handler. In GTK 2.0, the drawbuf is
       never drawn if this is installed as the default signal
       handler, but I do not understand why.  */
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(draw), "expose_event",
-                         GTK_SIGNAL_FUNC(_sc_drawbuf_expose), NULL);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(draw), "expose_event",
-                       (GCallback)_sc_drawbuf_expose, NULL);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(draw), "expose_event",
+                    (GCallback)_sc_drawbuf_expose, NULL);
 
 }
 
@@ -191,36 +175,22 @@ GType sc_drawbuf_get_type(void) {
    static GType sc_drawbuf_type = 0;
 
    if(sc_drawbuf_type == 0) {
-      #if GTK12_ENABLED
-         static const GtkTypeInfo sc_drawbuf_info = {
-            (char *)"ScDrawbuf",
-            sizeof(ScDrawbuf),
-            sizeof(ScDrawbufClass),
-            (GtkClassInitFunc)_sc_drawbuf_class_init,
-            (GtkObjectInitFunc)_sc_drawbuf_init_obj,
-            NULL,
-            NULL,
-            (GtkClassInitFunc)NULL
-         };
-         sc_drawbuf_type = gtk_type_unique(gtk_drawing_area_get_type(), &sc_drawbuf_info);
-      #else /* GTK 2.0 */
-         static const GTypeInfo sc_drawbuf_info = {
-            sizeof(ScDrawbufClass),          /* Size of the class object */
-            NULL,                            /* Base initializer */
-            NULL,                            /* Base finalizer */
-            (GClassInitFunc)_sc_drawbuf_class_init,
-                                             /* Class initializer */
-            NULL,                            /* Class finalizer */
-            NULL,                            /* Class data pointer */
-            sizeof(ScDrawbuf),               /* Size of an instance object */
-            0,                               /* Number of preallocs */
-            (GInstanceInitFunc)_sc_drawbuf_init_obj,
-                                             /* Instance initializer */
-            NULL                             /* Value table */
-         };
-         sc_drawbuf_type = g_type_register_static(gtk_drawing_area_get_type(), "ScDrawbuf",
-                                                  &sc_drawbuf_info, 0);
-      #endif /* GTK version? */
+      static const GTypeInfo sc_drawbuf_info = {
+         sizeof(ScDrawbufClass),          /* Size of the class object */
+         NULL,                            /* Base initializer */
+         NULL,                            /* Base finalizer */
+         (GClassInitFunc)_sc_drawbuf_class_init,
+                                          /* Class initializer */
+         NULL,                            /* Class finalizer */
+         NULL,                            /* Class data pointer */
+         sizeof(ScDrawbuf),               /* Size of an instance object */
+         0,                               /* Number of preallocs */
+         (GInstanceInitFunc)_sc_drawbuf_init_obj,
+                                          /* Instance initializer */
+         NULL                             /* Value table */
+      };
+      sc_drawbuf_type = g_type_register_static(gtk_drawing_area_get_type(), "ScDrawbuf",
+                                               &sc_drawbuf_info, 0);
    }
 
    return(sc_drawbuf_type);
