@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/slabel.h,v 1.5 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/slabel.h,v 1.7 2009-04-26 17:39:54 jacob Exp $ */
 /*
 
    xscorch - slabel.h         Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __slabel_h_included
@@ -31,9 +31,9 @@
 
 
 /* typecasts */
-#define  SC_LABEL(obj)           GTK_CHECK_CAST(obj, sc_label_get_type(), ScLabel)
-#define  SC_LABEL_CLASS(klass)   GTK_CHECK_CLASS_CAST(klass, sc_label_get_type(), ScLabelClass)
-#define  IS_SC_LABEL(obj)        GTK_CHECK_TYPE(obj, sc_label_get_type())
+#define  SC_LABEL(obj)           G_TYPE_CHECK_INSTANCE_CAST(obj, sc_label_get_type(), ScLabel)
+#define  SC_LABEL_CLASS(klass)   G_TYPE_CHECK_CLASS_CAST(klass, sc_label_get_type(), ScLabelClass)
+#define  IS_SC_LABEL(obj)        G_TYPE_CHECK_INSTANCE_TYPE(obj, sc_label_get_type())
 
 
 /* The ScLabel structure */
@@ -54,5 +54,3 @@ GtkWidget *sc_label_new(const char *text);
 
 
 #endif /* __slabel_h_included */
-
-
