@@ -1,7 +1,8 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/slinkcombo.h,v 1.5 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/slinkcombo.h,v 1.8 2009-06-02 07:37:43 jacob Exp $ */
 /*
 
    xscorch - slinkcombo.h     Copyright(c) 2000-2003 Justin David Smith
+                              Copyright(c) 2006 Jacob Luna Lundberg
    justins(at)chaos2.org      http://chaos2.org/
 
    Scorch combolist widgets
@@ -16,9 +17,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __slinkcombo_h_included
@@ -26,35 +27,38 @@
 
 
 #include <sgtk.h>
+
 #include <gtk/gtk.h>
-#include <gtk/gtkcombo.h>
 
 
 /* typecasts */
-#define  SC_LINK_COMBO(obj)          GTK_COMBO_CAST(obj, sc_link_combo_get_type(), ScLinkCombo)
-#define  SC_LINK_COMBO_CLASS(klass)  GTK_COMBO_CLASS_CAST(klass, sc_link_combo_get_type(), ScLinkComboClass)
-#define  IS_SC_LINK_COMBO(obj)       GTK_COMBO_TYPE(obj, sc_link_combo_get_type())
+#define  SC_LINK_COMBO(obj)          GTK_COMBO_BOX_CAST(obj, sc_link_combo_get_type(), ScLinkCombo)
+#define  SC_LINK_COMBO_CLASS(klass)  GTK_COMBO_BOX_CLASS_CAST(klass, sc_link_combo_get_type(), ScLinkComboClass)
+#define  IS_SC_LINK_COMBO(obj)       GTK_COMBO_BOX_TYPE(obj, sc_link_combo_get_type())
 
 
 /* The ScLinkCombo structure */
 typedef struct _ScLinkCombo {
-   GtkCombo parent;
-   int *value;
+   GtkComboBox parent;
 } ScLinkCombo;
 
-
 /* ScLinkComboClass structure */
 typedef struct _ScLinkComboClass {
-   GtkComboClass parent_class;
+   GtkComboBoxClass parent_class;
    void (*modified)(ScLinkCombo *spin, gpointer data);
 } ScLinkComboClass;
 
 
+/* Utility data struct for GTK to pass around */
+typedef struct _ScLinkComboData {
+   const char **entries;
+   int *value;
+} ScLinkComboData;
+
+
 /* LinkCombo initialisation and execution */
 GType sc_link_combo_get_type(void);
 GtkWidget *sc_link_combo_new(int *value, const char **entries);
 
 
 #endif /* __slinkcombo_h_included */
-
-
