@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/slinkentry.h,v 1.7 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/slinkentry.h,v 1.9 2009-04-26 17:39:54 jacob Exp $ */
 /*
 
    xscorch - slinkentry.h     Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __slinkentry_h_included
@@ -31,9 +31,9 @@
 
 
 /* typecasts */
-#define  SC_LINK_ENTRY(obj)          GTK_CHECK_CAST(obj, sc_link_entry_get_type(), ScLinkEntry)
-#define  SC_LINK_ENTRY_CLASS(klass)  GTK_CHECK_CLASS_CAST(klass, sc_link_entry_get_type(), ScLinkEntryClass)
-#define  IS_SC_LINK_ENTRY(obj)       GTK_CHECK_TYPE(obj, sc_link_entry_get_type())
+#define  SC_LINK_ENTRY(obj)          G_TYPE_CHECK_INSTANCE_CAST(obj, sc_link_entry_get_type(), ScLinkEntry)
+#define  SC_LINK_ENTRY_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST(klass, sc_link_entry_get_type(), ScLinkEntryClass)
+#define  IS_SC_LINK_ENTRY(obj)       G_TYPE_CHECK_INSTANCE_TYPE(obj, sc_link_entry_get_type())
 
 
 /* The ScLinkEntry structure */
@@ -58,5 +58,3 @@ void sc_link_entry_set_text(ScLinkEntry *entry, const char *value);
 
 
 #endif /* __slinkentry_h_included */
-
-
