@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/slinkspin.h,v 1.5 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/slinkspin.h,v 1.7 2009-04-26 17:39:54 jacob Exp $ */
 /*
 
    xscorch - slinkspin.h      Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __slinkspin_h_included
@@ -31,12 +31,13 @@
 
 
 /* typecasts */
-#define  SC_LINK_SPIN(obj)          GTK_CHECK_CAST(obj, sc_link_spin_get_type(), ScLinkSpin)
-#define  SC_LINK_SPIN_CLASS(klass)  GTK_CHECK_CLASS_CAST(klass, sc_link_spin_get_type(), ScLinkSpinClass)
-#define  IS_SC_LINK_SPIN(obj)       GTK_CHECK_TYPE(obj, sc_link_spin_get_type())
-#define  SC_LINK_SPINF(obj)         GTK_CHECK_CAST(obj, sc_link_spinf_get_type(), ScLinkSpinF)
-#define  SC_LINK_SPINF_CLASS(klass) GTK_CHECK_CLASS_CAST(klass, sc_link_spinf_get_type(), ScLinkSpinFClass)
-#define  IS_SC_LINK_SPINF(obj)      GTK_CHECK_TYPE(obj, sc_link_spinf_get_type())
+#define  SC_LINK_SPIN(obj)          G_TYPE_CHECK_INSTANCE_CAST(obj, sc_link_spin_get_type(), ScLinkSpin)
+#define  SC_LINK_SPIN_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST(klass, sc_link_spin_get_type(), ScLinkSpinClass)
+#define  IS_SC_LINK_SPIN(obj)       G_TYPE_CHECK_INSTANCE_TYPE(obj, sc_link_spin_get_type())
+
+#define  SC_LINK_SPINF(obj)         G_TYPE_CHECK_INSTANCE_CAST(obj, sc_link_spinf_get_type(), ScLinkSpinF)
+#define  SC_LINK_SPINF_CLASS(klass) G_TYPE_CHECK_CLASS_CAST(klass, sc_link_spinf_get_type(), ScLinkSpinFClass)
+#define  IS_SC_LINK_SPINF(obj)      G_TYPE_CHECK_INSTANCE_TYPE(obj, sc_link_spinf_get_type())
 
 
 /* The ScLinkSpin structure */
@@ -75,5 +76,3 @@ GtkWidget *sc_link_spinf_new(double *value, double min, double max, double step)
 
 
 #endif /* __slinkspin_h_included */
-
-
