@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swindow-gtk.c,v 1.31 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swindow-gtk.c,v 1.34 2011-07-31 19:05:20 jacob Exp $ */
 /*
 
    xscorch - swindow-gtk.c    Copyright(c) 2000-2004 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #define  __ALLOW_DEPRECATED_GDK__
@@ -79,7 +79,7 @@ void sc_window_timer_enable(sc_window *w_) {
 
    sc_window_gtk *w = (sc_window_gtk *)w_;
 
-   w->timer_id = gtk_timeout_add(SC_SLEEP_TIME, _sc_window_timeout_gtk, w);
+   w->timer_id = g_timeout_add(SC_SLEEP_TIME, _sc_window_timeout_gtk, w);
 
 }
 
@@ -89,13 +89,13 @@ void sc_window_timer_disable(sc_window *w_) {
 
    sc_window_gtk *w = (sc_window_gtk *)w_;
 
-   gtk_timeout_remove(w->timer_id);
+   g_source_remove(w->timer_id);
 
 }
 
 
 
-static void _sc_screen_expose_gtk(unused GtkWidget *widget, unused GdkEvent *event, gpointer data) {
+static void _sc_screen_expose_gtk(__libj_unused GtkWidget *widget, __libj_unused GdkEvent *event, gpointer data) {
 
    sc_window_gtk *w = data;
 
@@ -117,7 +117,7 @@ static void _sc_screen_expose_gtk(unused GtkWidget *widget, unused GdkEvent *eve
 
 
 
-static gint _sc_delete_event_gtk(unused GtkWidget *app, unused GdkEventAny *event, unused gpointer data) {
+static gint _sc_delete_event_gtk(__libj_unused GtkWidget *app, __libj_unused GdkEventAny *event, __libj_unused gpointer data) {
 
    #if SC_GTK_DEBUG_GTK && __debugging_macros
       SC_DEBUG_ENTER_();
@@ -330,7 +330,7 @@ static bool _sc_load_images(sc_window_gtk *w) {
 
 
 
-sc_window *sc_window_new(sc_config *c, unused int argc, unused char **argv) {
+sc_window *sc_window_new(sc_config *c, __libj_unused int argc, __libj_unused char **argv) {
 
    sc_window_gtk *w;
    GtkWidget *cont;
@@ -360,23 +360,9 @@ sc_window *sc_window_new(sc_config *c, unused int argc, unused char **argv) {
    /* Create the window */
    w->app = gtk_window_new(GTK_WINDOW_TOPLEVEL);
    gtk_window_set_title(GTK_WINDOW(w->app), "XScorch");
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(w->app), "delete_event",
-                         GTK_SIGNAL_FUNC(_sc_delete_event_gtk), w);
-      gtk_window_set_policy(GTK_WINDOW(w->app), FALSE, FALSE, TRUE);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(w->app), "delete_event",
-                       (GCallback)_sc_delete_event_gtk, w);
-      gtk_window_set_resizable(GTK_WINDOW(w->app), FALSE);
-   #endif /* GTK version? */
-
-   /* Setup tooltips */
-   w->tooltips = gtk_tooltips_new();
-   if(w->c->options.tooltips) gtk_tooltips_enable(w->tooltips);
-   else                       gtk_tooltips_disable(w->tooltips);
-   #if GTK12_ENABLED
-      gtk_tooltips_set_delay(w->tooltips, SC_GTK_TOOLTIP_DELAY);
-   #endif /* GTK 1.2? */
+   g_signal_connect(G_OBJECT(w->app), "delete_event",
+                    (GCallback)_sc_delete_event_gtk, w);
+   gtk_window_set_resizable(GTK_WINDOW(w->app), FALSE);
 
    /* Create the main (vertical) container */
    cont = gtk_vbox_new(FALSE, 0);
@@ -397,13 +383,8 @@ sc_window *sc_window_new(sc_config *c, unused int argc, unused char **argv) {
    /*w->border = sc_display_new(w->c->fieldwidth + 4, w->c->fieldheight + 4);
    gtk_box_pack_start(GTK_BOX(cont), w->border, TRUE, TRUE, 0);*/
    w->screen = sc_display_new(w->c->fieldwidth, w->c->fieldheight);
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(sc_display_get_drawbuf(SC_DISPLAY(w->screen))),
-                         "expose_event", GTK_SIGNAL_FUNC(_sc_screen_expose_gtk), w);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(sc_display_get_drawbuf(SC_DISPLAY(w->screen))),
-                       "expose_event", (GCallback)_sc_screen_expose_gtk, w);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(sc_display_get_drawbuf(SC_DISPLAY(w->screen))),
+                    "expose_event", (GCallback)_sc_screen_expose_gtk, w);
    /*gtk_fixed_put(GTK_FIXED(w->border), w->screen, 2, 2);*/
    gtk_box_pack_start(GTK_BOX(cont), w->screen, TRUE, TRUE, 0);
 
@@ -430,13 +411,8 @@ sc_window *sc_window_new(sc_config *c, unused int argc, unused char **argv) {
    w->ready = TRUE;
 
    /* connect after loading, just to retain sanity. */
-   #if GTK12_ENABLED
-      gtk_signal_connect(GTK_OBJECT(w->app), "key_press_event",
-                         GTK_SIGNAL_FUNC(_sc_window_keypress_gtk), w);
-   #else /* GTK 2.0 */
-      g_signal_connect(G_OBJECT(w->app), "key_press_event",
-                       (GCallback)_sc_window_keypress_gtk, w);
-   #endif /* GTK version? */
+   g_signal_connect(G_OBJECT(w->app), "key_press_event",
+                    (GCallback)_sc_window_keypress_gtk, w);
 
    /* Return the structure */
    return((sc_window *)w);
@@ -448,11 +424,7 @@ sc_window *sc_window_new(sc_config *c, unused int argc, unused char **argv) {
 static inline void _sc_window_unref_land_buffer(sc_window_gtk *w) {
 
    if(w->landbuffer != NULL) {
-      #if GTK12_ENABLED
-         gdk_pixmap_unref(w->landbuffer);
-      #else /* GTK 2.0 */
-         g_object_unref(w->landbuffer);
-      #endif /* GTK version? */
+      g_object_unref(w->landbuffer);
    }
 
 }
@@ -499,7 +471,7 @@ void sc_window_idle(sc_window *w_) {
 
 
 
-void sc_window_message(unused sc_window *w_, const char *title, const char *msg) {
+void sc_window_message(__libj_unused sc_window *w_, const char *title, const char *msg) {
 
    sc_dialog_message(title, msg);
 
@@ -606,13 +578,13 @@ void sc_window_load_fonts(sc_window_gtk *w) {
       gdk_font_ref(w->bold_fixed_font);
    }
 
-
 }
 
 
 
 void sc_window_unload_fonts(sc_window_gtk *w) {
 
+int i;
    assert(w != NULL);
 
    if(w->fixed_font != NULL)        gdk_font_unref(w->fixed_font);
