@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sgtk/swindow-gtk.h,v 1.14 2004/02/26 06:34:55 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sgtk/swindow-gtk.h,v 1.16 2009-04-26 17:39:51 jacob Exp $ */
 /*
    
    xscorch - swindow-gtk.h    Copyright(c) 2000-2003 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __swindow_gtk_h_included
@@ -47,6 +47,7 @@ struct _sc_config;
 /* Main window structure */
 typedef struct _sc_window_gtk {
    struct _sc_config *c;                  /* Config structure */
+int buffer_a[1024];
    struct _sc_color_gtk *colormap;        /* GTK allocated colors */
    struct _sc_expl_cache_gtk *explcache;  /* List of drawn explosions */
    guint state;                           /* ? */
@@ -74,7 +75,6 @@ typedef struct _sc_window_gtk {
    GtkWidget *net_disconnect;
    GtkWidget *net_chat;
    GtkWidget *net_status;
-   GtkTooltips *tooltips;
 } sc_window_gtk;
 
 
