@@ -1,10 +1,10 @@
-/* $Header: /fridge/cvs/xscorch/snet/snetclient.c,v 1.25 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/snet/snetclient.c,v 1.28 2011-08-01 00:01:43 jacob Exp $ */
 /*
 
    xscorch - snetclient.c     Copyright(c) 2000-2003 Justin David Smith
                               Copyright(c) 2001-2003 Jacob Luna Lundberg
    justins(at)chaos2.org      http://chaos2.org/
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Client control loop
 
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <errno.h>
@@ -573,7 +573,9 @@ static bool _sc_net_process_message(sc_config *c, sc_client *cli, sc_packet *pac
       memcpy(buffer, packet->data, min(packet->data_size, SC_NET_BUFFER_SIZE - 1));
       buffer[min(packet->data_size, SC_NET_BUFFER_SIZE - 1)] = '\0';
       sc_net_set_info("chat", buffer);
+#if 0 /* TEMP - Chat is broken in GTK 2.  As in, this does not compile. */
       sc_chat_window_update(c->window, buffer);
+#endif
       break;
    case SC_NET_SVR_CONFIG_DATA:
       sc_net_cli_recv_config(c, cli, packet);
