@@ -1,10 +1,10 @@
-/* $Header: /fridge/cvs/xscorch/snet/snetconnect.c,v 1.13 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/snet/snetconnect.c,v 1.17 2011-08-01 00:01:43 jacob Exp $ */
 /*
    
    xscorch - snetconnect.c    Copyright(c) 2000-2003 Justin David Smith
-                              Copyright(c) 2001-2003 Jacob Luna Lundberg
+                              Copyright(c) 2001-2011 Jacob Luna Lundberg
    justins(at)chaos2.org      http://chaos2.org/
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Network connection open, close
 
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <errno.h>
@@ -153,7 +153,7 @@ sc_client *sc_net_client_new(const char *name, const char *hostname, int port) {
 
    /* setup client destination address */
    memset((char *)&cli->server.address, '\0', sizeof(addr));
-   memcpy((char *)&cli->server.address.sin_addr, host_info->h_addr, host_info->h_length);
+   memcpy((char *)&cli->server.address.sin_addr, host_info->HOSTENT_H_ADDR, host_info->h_length);
    cli->server.address.sin_family = host_info->h_addrtype;
    cli->server.address.sin_port = htons(port);
 
