@@ -1,10 +1,10 @@
-/* $Header: /fridge/cvs/xscorch/snet/snetint.h,v 1.12 2004/02/26 06:34:56 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/snet/snetint.h,v 1.14 2011-08-01 00:01:43 jacob Exp $ */
 /*
    
    xscorch - snetint.h        Copyright(c) 2000-2003 Justin David Smith
                               Copyright(c) 2001      Jacob Luna Lundberg
    justins(at)chaos2.org      http://chaos2.org/
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
     
    Internal network header files
     
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __snetint_h_included
