@@ -1,9 +1,9 @@
-/* $Header: /fridge/cvs/xscorch/snet/tcpnet/tn_internal.c,v 1.6 2003/02/25 03:59:39 jacob Exp $
+/* $Header: /fridge/cvs/xscorch/snet/tcpnet/tn_internal.c,v 1.8 2011-08-01 00:01:44 jacob Exp $
  *
  * tn_internal.c
  * File revision 6.xscorch
  * Internal methods for tcp net.
- * (c) 2001-2003 Jacob Lundberg, jacob@chaos2.org
+ * (c) 2001-2003 Jacob Lundberg, jacob(at)gnifty.net
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
 
