@@ -1,9 +1,9 @@
-/* $Header: /fridge/cvs/xscorch/snet/tcpnet/tn_write.c,v 1.2 2001/07/26 21:41:07 jacob Exp $
+/* $Header: /fridge/cvs/xscorch/snet/tcpnet/tn_write.c,v 1.4 2011-08-01 00:01:44 jacob Exp $
  *
  * tn_write.c
  * File revision 2.xscorch
  * Packet writing via tcp net.
- * (c) 2001 Jacob Lundberg, jacob@chaos2.org
+ * (c) 2001 Jacob Lundberg, jacob(at)gnifty.net
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
 
