@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/ssound/ssoundnull.c,v 1.4 2004/02/26 06:34:57 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/ssound/ssoundnull.c,v 1.6 2009-04-26 17:39:59 jacob Exp $ */
 /*
    
    xscorch - ssoundnull.c     Copyright(c) 2001,2000 Justin David Smith
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #include <ssound.h>
@@ -32,7 +32,7 @@ void sc_sound_init(void) {
 
 
 
-sc_sound *sc_sound_new(unused int enable, unused int hqmixer) {
+sc_sound *sc_sound_new(__libj_unused int enable, __libj_unused int hqmixer) {
 
    return(NULL);
    
@@ -40,7 +40,7 @@ sc_sound *sc_sound_new(unused int enable, unused int hqmixer) {
 
 
 
-void sc_sound_config(unused sc_sound **s, unused int enable, unused int hqmixer) {
+void sc_sound_config(__libj_unused sc_sound **s, __libj_unused int enable, __libj_unused int hqmixer) {
 
 }
 
@@ -56,31 +56,31 @@ void sc_sound_free(sc_sound **s) {
 
 
 
-void sc_sound_start(unused sc_sound *s, unused sc_sound_music id) {
+void sc_sound_start(__libj_unused sc_sound *s, __libj_unused sc_sound_music id) {
 
 }
 
 
 
-void sc_sound_update(unused sc_sound *s) {
+void sc_sound_update(__libj_unused sc_sound *s) {
    
 }
 
 
 
-void sc_sound_stop(unused sc_sound *s) {
+void sc_sound_stop(__libj_unused sc_sound *s) {
 
 }
 
 
 
-void sc_sound_pause(unused sc_sound *s) {
+void sc_sound_pause(__libj_unused sc_sound *s) {
 
 }
 
 
 
-void sc_sound_unpause(unused sc_sound *s) {
+void sc_sound_unpause(__libj_unused sc_sound *s) {
 
 }
 
