@@ -1,4 +1,4 @@
-/* $Header: /fridge/cvs/xscorch/sutil/randserv.h,v 1.2 2001/04/07 19:49:00 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sutil/randserv.h,v 1.3 2009-04-26 17:40:01 jacob Exp $ */
 /*--------------------------------------------------------------------
  *
  *  randserv.h -- Random deviate generator
@@ -19,7 +19,7 @@
  *  along with this program; if not, write to 
  *
  *    The Free Software Foundation, Inc.
- *    59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  * 
  */
 
