@@ -1,8 +1,8 @@
-/* $Header: /fridge/cvs/xscorch/sutil/shash.h,v 1.7 2004/02/26 06:34:57 justins Exp $ */
+/* $Header: /fridge/cvs/xscorch/sutil/shash.h,v 1.9 2011-08-01 00:01:44 jacob Exp $ */
 /*
 
    xscorch - shash.h          Copyright(c) 2001-2003 Jacob Luna Lundberg
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    A very slim hashing implementation for xscorch.
 
@@ -16,9 +16,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #ifndef __shash_h_included
