@@ -1,10 +1,10 @@
-/* $Header: /fridge/cvs/xscorch/xscorch.c,v 1.11 2004/03/10 21:52:42 jacob Exp $ */
+/* $Header: /fridge/cvs/xscorch/xscorch.c,v 1.13 2011-08-01 00:01:39 jacob Exp $ */
 /*
 
    xscorch - xscorch.c        Copyright(c) 2000-2004 Justin David Smith
                               Copyright(c) 2000-2004 Jacob Luna Lundberg
    justins(at)chaos2.org      http://chaos2.org/
-   jacob(at)chaos2.org        http://chaos2.org/~jacob
+   jacob(at)gnifty.net        http://www.gnifty.net/
 
    Scorched Earth, main function
 
@@ -18,9 +18,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 */
 #define  _POSIX_SOURCE     /* Needed for signal handling */
